# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from .._models import BaseModel
from .tiktok_configuration import TiktokConfiguration
from .bluesky_configuration_dto import BlueskyConfigurationDto
from .threads_configuration_dto import ThreadsConfigurationDto
from .twitter_configuration_dto import TwitterConfigurationDto
from .youtube_configuration_dto import YoutubeConfigurationDto
from .facebook_configuration_dto import FacebookConfigurationDto
from .linkedin_configuration_dto import LinkedinConfigurationDto
from .instagram_configuration_dto import InstagramConfigurationDto
from .pinterest_configuration_dto import PinterestConfigurationDto

__all__ = ["PlatformConfigurationsDto"]


class PlatformConfigurationsDto(BaseModel):
    bluesky: Optional[BlueskyConfigurationDto] = None
    """Bluesky configuration"""

    facebook: Optional[FacebookConfigurationDto] = None
    """Facebook configuration"""

    instagram: Optional[InstagramConfigurationDto] = None
    """Instagram configuration"""

    linkedin: Optional[LinkedinConfigurationDto] = None
    """LinkedIn configuration"""

    pinterest: Optional[PinterestConfigurationDto] = None
    """Pinterest configuration"""

    threads: Optional[ThreadsConfigurationDto] = None
    """Threads configuration"""

    tiktok: Optional[TiktokConfiguration] = None
    """TikTok configuration"""

    tiktok_business: Optional[TiktokConfiguration] = None
    """TikTok configuration"""

    x: Optional[TwitterConfigurationDto] = None
    """Twitter configuration"""

    youtube: Optional[YoutubeConfigurationDto] = None
    """YouTube configuration"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .._models import BaseModel

__all__ = ["MediaCreateUploadURLResponse"]


class MediaCreateUploadURLResponse(BaseModel):
    media_url: str
    """The public URL for the media, to use once file has been uploaded"""

    upload_url: str
    """The signed upload URL for the client to upload the file"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from post_for_me import PostForMe, AsyncPostForMe
from tests.utils import assert_matches_type
from post_for_me.types import (
    SocialAccount,
    SocialAccountListResponse,
    SocialAccountDisconnectResponse,
    SocialAccountCreateAuthURLResponse,
)
from post_for_me._utils import parse_datetime

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestSocialAccounts:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_create(self, client: PostForMe) -> None:
        social_account = client.social_accounts.create(
            access_token="access_token",
            access_token_expires_at=parse_datetime("2019-12-27T18:11:19.117Z"),
            platform="facebook",
            user_id="user_id",
        )
        assert_matches_type(SocialAccount, social_account, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_create_with_all_params(self, client: PostForMe) -> None:
        social_account = client.social_accounts.create(
            access_token="access_token",
            access_token_expires_at=parse_datetime("2019-12-27T18:11:19.117Z"),
            platform="facebook",
            user_id="user_id",
            external_id="external_id",
            metadata={},
            refresh_token="refresh_token",
            refresh_token_expires_at=parse_datetime("2019-12-27T18:11:19.117Z"),
            username="username",
        )
        assert_matches_type(SocialAccount, social_account, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_create(self, client: PostForMe) -> None:
        response = client.social_accounts.with_raw_response.create(
            access_token="access_token",
            access_token_expires_at=parse_datetime("2019-12-27T18:11:19.117Z"),
            platform="facebook",
            user_id="user_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        social_account = response.parse()
        assert_matches_type(SocialAccount, social_account, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_create(self, client: PostForMe) -> None:
        with client.social_accounts.with_streaming_response.create(
            access_token="access_token",
            access_token_expires_at=parse_datetime("2019-12-27T18:11:19.117Z"),
            platform="facebook",
            user_id="user_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            social_account = response.parse()
            assert_matches_type(SocialAccount, social_account, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_retrieve(self, client: PostForMe) -> None:
        social_account = client.social_accounts.retrieve(
            "id",
        )
        assert_matches_type(SocialAccount, social_account, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_retrieve(self, client: PostForMe) -> None:
        response = client.social_accounts.with_raw_response.retrieve(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        social_account = response.parse()
        assert_matches_type(SocialAccount, social_account, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_retrieve(self, client: PostForMe) -> None:
        with client.social_accounts.with_streaming_response.retrieve(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            social_account = response.parse()
            assert_matches_type(SocialAccount, social_account, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_retrieve(self, client: PostForMe) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.social_accounts.with_raw_response.retrieve(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_update(self, client: PostForMe) -> None:
        social_account = client.social_accounts.update(
            id="id",
        )
        assert_matches_type(SocialAccount, social_account, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_update_with_all_params(self, client: PostForMe) -> None:
        social_account = client.social_accounts.update(
            id="id",
            external_id="external_id",
            username="username",
        )
        assert_matches_type(SocialAccount, social_account, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_update(self, client: PostForMe) -> None:
        response = client.social_accounts.with_raw_response.update(
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        social_account = response.parse()
        assert_matches_type(SocialAccount, social_account, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_update(self, client: PostForMe) -> None:
        with client.social_accounts.with_streaming_response.update(
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            social_account = response.parse()
            assert_matches_type(SocialAccount, social_account, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_update(self, client: PostForMe) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.social_accounts.with_raw_response.update(
                id="",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_list(self, client: PostForMe) -> None:
        social_account = client.social_accounts.list()
        assert_matches_type(SocialAccountListResponse, social_account, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_list_with_all_params(self, client: PostForMe) -> None:
        social_account = client.social_accounts.list(
            id=["string"],
            external_id=["string"],
            limit=0,
            offset=0,
            platform=["string"],
            username=["string"],
        )
        assert_matches_type(SocialAccountListResponse, social_account, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_list(self, client: PostForMe) -> None:
        response = client.social_accounts.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        social_account = response.parse()
        assert_matches_type(SocialAccountListResponse, social_account, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_list(self, client: PostForMe) -> None:
        with client.social_accounts.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            social_account = response.parse()
            assert_matches_type(SocialAccountListResponse, social_account, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_create_auth_url(self, client: PostForMe) -> None:
        social_account = client.social_accounts.create_auth_url(
            platform="platform",
        )
        assert_matches_type(SocialAccountCreateAuthURLResponse, social_account, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_create_auth_url_with_all_params(self, client: PostForMe) -> None:
        social_account = client.social_accounts.create_auth_url(
            platform="platform",
            external_id="external_id",
            permissions=["posts", "feeds"],
            platform_data={
                "bluesky": {
                    "app_password": "app_password",
                    "handle": "handle",
                },
                "facebook": {"permission_overrides": [[{}]]},
                "instagram": {
                    "connection_type": "instagram",
                    "permission_overrides": [[{}]],
                },
                "linkedin": {
                    "connection_type": "personal",
                    "permission_overrides": [[{}]],
                },
                "pinterest": {"permission_overrides": [[{}]]},
                "threads": {"permission_overrides": [[{}]]},
                "tiktok": {"permission_overrides": [[{}]]},
                "tiktok_business": {"permission_overrides": [[{}]]},
                "youtube": {"permission_overrides": [[{}]]},
            },
            redirect_url_override="redirect_url_override",
        )
        assert_matches_type(SocialAccountCreateAuthURLResponse, social_account, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_create_auth_url(self, client: PostForMe) -> None:
        response = client.social_accounts.with_raw_response.create_auth_url(
            platform="platform",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        social_account = response.parse()
        assert_matches_type(SocialAccountCreateAuthURLResponse, social_account, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_create_auth_url(self, client: PostForMe) -> None:
        with client.social_accounts.with_streaming_response.create_auth_url(
            platform="platform",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            social_account = response.parse()
            assert_matches_type(SocialAccountCreateAuthURLResponse, social_account, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_disconnect(self, client: PostForMe) -> None:
        social_account = client.social_accounts.disconnect(
            "id",
        )
        assert_matches_type(SocialAccountDisconnectResponse, social_account, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_disconnect(self, client: PostForMe) -> None:
        response = client.social_accounts.with_raw_response.disconnect(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        social_account = response.parse()
        assert_matches_type(SocialAccountDisconnectResponse, social_account, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_disconnect(self, client: PostForMe) -> None:
        with client.social_accounts.with_streaming_response.disconnect(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            social_account = response.parse()
            assert_matches_type(SocialAccountDisconnectResponse, social_account, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_disconnect(self, client: PostForMe) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.social_accounts.with_raw_response.disconnect(
                "",
            )


class TestAsyncSocialAccounts:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_create(self, async_client: AsyncPostForMe) -> None:
        social_account = await async_client.social_accounts.create(
            access_token="access_token",
            access_token_expires_at=parse_datetime("2019-12-27T18:11:19.117Z"),
            platform="facebook",
            user_id="user_id",
        )
        assert_matches_type(SocialAccount, social_account, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_create_with_all_params(self, async_client: AsyncPostForMe) -> None:
        social_account = await async_client.social_accounts.create(
            access_token="access_token",
            access_token_expires_at=parse_datetime("2019-12-27T18:11:19.117Z"),
            platform="facebook",
            user_id="user_id",
            external_id="external_id",
            metadata={},
            refresh_token="refresh_token",
            refresh_token_expires_at=parse_datetime("2019-12-27T18:11:19.117Z"),
            username="username",
        )
        assert_matches_type(SocialAccount, social_account, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_create(self, async_client: AsyncPostForMe) -> None:
        response = await async_client.social_accounts.with_raw_response.create(
            access_token="access_token",
            access_token_expires_at=parse_datetime("2019-12-27T18:11:19.117Z"),
            platform="facebook",
            user_id="user_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        social_account = await response.parse()
        assert_matches_type(SocialAccount, social_account, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_create(self, async_client: AsyncPostForMe) -> None:
        async with async_client.social_accounts.with_streaming_response.create(
            access_token="access_token",
            access_token_expires_at=parse_datetime("2019-12-27T18:11:19.117Z"),
            platform="facebook",
            user_id="user_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            social_account = await response.parse()
            assert_matches_type(SocialAccount, social_account, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_retrieve(self, async_client: AsyncPostForMe) -> None:
        social_account = await async_client.social_accounts.retrieve(
            "id",
        )
        assert_matches_type(SocialAccount, social_account, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_retrieve(self, async_client: AsyncPostForMe) -> None:
        response = await async_client.social_accounts.with_raw_response.retrieve(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        social_account = await response.parse()
        assert_matches_type(SocialAccount, social_account, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_retrieve(self, async_client: AsyncPostForMe) -> None:
        async with async_client.social_accounts.with_streaming_response.retrieve(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            social_account = await response.parse()
            assert_matches_type(SocialAccount, social_account, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_retrieve(self, async_client: AsyncPostForMe) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.social_accounts.with_raw_response.retrieve(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_update(self, async_client: AsyncPostForMe) -> None:
        social_account = await async_client.social_accounts.update(
            id="id",
        )
        assert_matches_type(SocialAccount, social_account, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_update_with_all_params(self, async_client: AsyncPostForMe) -> None:
        social_account = await async_client.social_accounts.update(
            id="id",
            external_id="external_id",
            username="username",
        )
        assert_matches_type(SocialAccount, social_account, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_update(self, async_client: AsyncPostForMe) -> None:
        response = await async_client.social_accounts.with_raw_response.update(
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        social_account = await response.parse()
        assert_matches_type(SocialAccount, social_account, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_update(self, async_client: AsyncPostForMe) -> None:
        async with async_client.social_accounts.with_streaming_response.update(
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            social_account = await response.parse()
            assert_matches_type(SocialAccount, social_account, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_update(self, async_client: AsyncPostForMe) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.social_accounts.with_raw_response.update(
                id="",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_list(self, async_client: AsyncPostForMe) -> None:
        social_account = await async_client.social_accounts.list()
        assert_matches_type(SocialAccountListResponse, social_account, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_list_with_all_params(self, async_client: AsyncPostForMe) -> None:
        social_account = await async_client.social_accounts.list(
            id=["string"],
            external_id=["string"],
            limit=0,
            offset=0,
            platform=["string"],
            username=["string"],
        )
        assert_matches_type(SocialAccountListResponse, social_account, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_list(self, async_client: AsyncPostForMe) -> None:
        response = await async_client.social_accounts.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        social_account = await response.parse()
        assert_matches_type(SocialAccountListResponse, social_account, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_list(self, async_client: AsyncPostForMe) -> None:
        async with async_client.social_accounts.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            social_account = await response.parse()
            assert_matches_type(SocialAccountListResponse, social_account, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_create_auth_url(self, async_client: AsyncPostForMe) -> None:
        social_account = await async_client.social_accounts.create_auth_url(
            platform="platform",
        )
        assert_matches_type(SocialAccountCreateAuthURLResponse, social_account, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_create_auth_url_with_all_params(self, async_client: AsyncPostForMe) -> None:
        social_account = await async_client.social_accounts.create_auth_url(
            platform="platform",
            external_id="external_id",
            permissions=["posts", "feeds"],
            platform_data={
                "bluesky": {
                    "app_password": "app_password",
                    "handle": "handle",
                },
                "facebook": {"permission_overrides": [[{}]]},
                "instagram": {
                    "connection_type": "instagram",
                    "permission_overrides": [[{}]],
                },
                "linkedin": {
                    "connection_type": "personal",
                    "permission_overrides": [[{}]],
                },
                "pinterest": {"permission_overrides": [[{}]]},
                "threads": {"permission_overrides": [[{}]]},
                "tiktok": {"permission_overrides": [[{}]]},
                "tiktok_business": {"permission_overrides": [[{}]]},
                "youtube": {"permission_overrides": [[{}]]},
            },
            redirect_url_override="redirect_url_override",
        )
        assert_matches_type(SocialAccountCreateAuthURLResponse, social_account, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_create_auth_url(self, async_client: AsyncPostForMe) -> None:
        response = await async_client.social_accounts.with_raw_response.create_auth_url(
            platform="platform",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        social_account = await response.parse()
        assert_matches_type(SocialAccountCreateAuthURLResponse, social_account, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_create_auth_url(self, async_client: AsyncPostForMe) -> None:
        async with async_client.social_accounts.with_streaming_response.create_auth_url(
            platform="platform",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            social_account = await response.parse()
            assert_matches_type(SocialAccountCreateAuthURLResponse, social_account, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_disconnect(self, async_client: AsyncPostForMe) -> None:
        social_account = await async_client.social_accounts.disconnect(
            "id",
        )
        assert_matches_type(SocialAccountDisconnectResponse, social_account, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_disconnect(self, async_client: AsyncPostForMe) -> None:
        response = await async_client.social_accounts.with_raw_response.disconnect(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        social_account = await response.parse()
        assert_matches_type(SocialAccountDisconnectResponse, social_account, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_disconnect(self, async_client: AsyncPostForMe) -> None:
        async with async_client.social_accounts.with_streaming_response.disconnect(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            social_account = await response.parse()
            assert_matches_type(SocialAccountDisconnectResponse, social_account, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_disconnect(self, async_client: AsyncPostForMe) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.social_accounts.with_raw_response.disconnect(
                "",
            )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List
from typing_extensions import Literal, TypedDict

from .._types import SequenceNotStr

__all__ = ["SocialAccountFeedListParams"]


class SocialAccountFeedListParams(TypedDict, total=False):
    cursor: str
    """Cursor identifying next page of results"""

    expand: List[Literal["metrics"]]
    """Expand additional data in the response.

    Currently supports: "metrics" to include post analytics data.
    """

    external_post_id: SequenceNotStr[str]
    """Filter by Post for Me Social Postexternal ID.

    Multiple values imply OR logic (e.g.,
    ?external_post_id=xxxxxx&external_post_id=yyyyyy).
    """

    limit: float
    """
    Number of items to return; Note: some platforms will have different max limits,
    in the case the provided limit is over the platform's limit we will return the
    max allowed by the platform.
    """

    platform_post_id: SequenceNotStr[str]
    """Filter by the platform's id(s).

    Multiple values imply OR logic (e.g.,
    ?social_post_id=spr_xxxxxx&social_post_id=spr_yyyyyy).
    """

    social_post_id: SequenceNotStr[str]
    """Filter by Post for Me Social Post id(s).

    Multiple values imply OR logic (e.g.,
    ?social_post_id=sp_xxxxxx&social_post_id=sp_yyyyyy).
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import TypedDict

from .tiktok_configuration_param import TiktokConfigurationParam
from .bluesky_configuration_dto_param import BlueskyConfigurationDtoParam
from .threads_configuration_dto_param import ThreadsConfigurationDtoParam
from .twitter_configuration_dto_param import TwitterConfigurationDtoParam
from .youtube_configuration_dto_param import YoutubeConfigurationDtoParam
from .facebook_configuration_dto_param import FacebookConfigurationDtoParam
from .linkedin_configuration_dto_param import LinkedinConfigurationDtoParam
from .instagram_configuration_dto_param import InstagramConfigurationDtoParam
from .pinterest_configuration_dto_param import PinterestConfigurationDtoParam

__all__ = ["PlatformConfigurationsDtoParam"]


class PlatformConfigurationsDtoParam(TypedDict, total=False):
    bluesky: Optional[BlueskyConfigurationDtoParam]
    """Bluesky configuration"""

    facebook: Optional[FacebookConfigurationDtoParam]
    """Facebook configuration"""

    instagram: Optional[InstagramConfigurationDtoParam]
    """Instagram configuration"""

    linkedin: Optional[LinkedinConfigurationDtoParam]
    """LinkedIn configuration"""

    pinterest: Optional[PinterestConfigurationDtoParam]
    """Pinterest configuration"""

    threads: Optional[ThreadsConfigurationDtoParam]
    """Threads configuration"""

    tiktok: Optional[TiktokConfigurationParam]
    """TikTok configuration"""

    tiktok_business: Optional[TiktokConfigurationParam]
    """TikTok configuration"""

    x: Optional[TwitterConfigurationDtoParam]
    """Twitter configuration"""

    youtube: Optional[YoutubeConfigurationDtoParam]
    """YouTube configuration"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .social_post import SocialPost as SocialPost
from .platform_post import PlatformPost as PlatformPost
from .social_account import SocialAccount as SocialAccount
from .social_post_result import SocialPostResult as SocialPostResult
from .tiktok_configuration import TiktokConfiguration as TiktokConfiguration
from .social_post_list_params import SocialPostListParams as SocialPostListParams
from .bluesky_configuration_dto import BlueskyConfigurationDto as BlueskyConfigurationDto
from .social_post_create_params import SocialPostCreateParams as SocialPostCreateParams
from .social_post_list_response import SocialPostListResponse as SocialPostListResponse
from .social_post_update_params import SocialPostUpdateParams as SocialPostUpdateParams
from .threads_configuration_dto import ThreadsConfigurationDto as ThreadsConfigurationDto
from .twitter_configuration_dto import TwitterConfigurationDto as TwitterConfigurationDto
from .youtube_configuration_dto import YoutubeConfigurationDto as YoutubeConfigurationDto
from .facebook_configuration_dto import FacebookConfigurationDto as FacebookConfigurationDto
from .linkedin_configuration_dto import LinkedinConfigurationDto as LinkedinConfigurationDto
from .social_account_list_params import SocialAccountListParams as SocialAccountListParams
from .tiktok_configuration_param import TiktokConfigurationParam as TiktokConfigurationParam
from .instagram_configuration_dto import InstagramConfigurationDto as InstagramConfigurationDto
from .pinterest_configuration_dto import PinterestConfigurationDto as PinterestConfigurationDto
from .platform_configurations_dto import PlatformConfigurationsDto as PlatformConfigurationsDto
from .social_post_delete_response import SocialPostDeleteResponse as SocialPostDeleteResponse
from .social_account_create_params import SocialAccountCreateParams as SocialAccountCreateParams
from .social_account_list_response import SocialAccountListResponse as SocialAccountListResponse
from .social_account_update_params import SocialAccountUpdateParams as SocialAccountUpdateParams
from .social_post_result_list_params import SocialPostResultListParams as SocialPostResultListParams
from .bluesky_configuration_dto_param import BlueskyConfigurationDtoParam as BlueskyConfigurationDtoParam
from .social_account_feed_list_params import SocialAccountFeedListParams as SocialAccountFeedListParams
from .threads_configuration_dto_param import ThreadsConfigurationDtoParam as ThreadsConfigurationDtoParam
from .twitter_configuration_dto_param import TwitterConfigurationDtoParam as TwitterConfigurationDtoParam
from .youtube_configuration_dto_param import YoutubeConfigurationDtoParam as YoutubeConfigurationDtoParam
from .facebook_configuration_dto_param import FacebookConfigurationDtoParam as FacebookConfigurationDtoParam
from .linkedin_configuration_dto_param import LinkedinConfigurationDtoParam as LinkedinConfigurationDtoParam
from .media_create_upload_url_response import MediaCreateUploadURLResponse as MediaCreateUploadURLResponse
from .social_post_result_list_response import SocialPostResultListResponse as SocialPostResultListResponse
from .instagram_configuration_dto_param import InstagramConfigurationDtoParam as InstagramConfigurationDtoParam
from .pinterest_configuration_dto_param import PinterestConfigurationDtoParam as PinterestConfigurationDtoParam
from .platform_configurations_dto_param import PlatformConfigurationsDtoParam as PlatformConfigurationsDtoParam
from .social_account_feed_list_response import SocialAccountFeedListResponse as SocialAccountFeedListResponse
from .social_account_disconnect_response import SocialAccountDisconnectResponse as SocialAccountDisconnectResponse
from .social_account_create_auth_url_params import SocialAccountCreateAuthURLParams as SocialAccountCreateAuthURLParams
from .social_account_create_auth_url_response import (
    SocialAccountCreateAuthURLResponse as SocialAccountCreateAuthURLResponse,
)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List
from typing_extensions import Literal, TypedDict

from .._types import SequenceNotStr

__all__ = ["SocialPostListParams"]


class SocialPostListParams(TypedDict, total=False):
    external_id: SequenceNotStr[str]
    """Filter by external ID. Multiple values imply OR logic."""

    limit: float
    """Number of items to return"""

    offset: float
    """Number of items to skip"""

    platform: List[
        Literal["bluesky", "facebook", "instagram", "linkedin", "pinterest", "threads", "tiktok", "x", "youtube"]
    ]
    """Filter by platforms. Multiple values imply OR logic."""

    social_account_id: SequenceNotStr[str]
    """Filter by social account ID. Multiple values imply OR logic."""

    status: List[Literal["draft", "scheduled", "processing", "processed"]]
    """Filter by post status. Multiple values imply OR logic."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from .._types import Body, Query, Headers, NotGiven, not_given
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.media_create_upload_url_response import MediaCreateUploadURLResponse

__all__ = ["MediaResource", "AsyncMediaResource"]


class MediaResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> MediaResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/DayMoonDevelopment/post-for-me-python#accessing-raw-response-data-eg-headers
        """
        return MediaResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> MediaResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/DayMoonDevelopment/post-for-me-python#with_streaming_response
        """
        return MediaResourceWithStreamingResponse(self)

    def create_upload_url(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> MediaCreateUploadURLResponse:
        """
        To upload media to attach to your post, make a `POST` request to the
        `/media/create-upload-url` endpoint.

        You'll receive the public url of your media item (which can be used when making
        a post) and will include an `upload_url` which is a signed URL of the storage
        location for uploading your file to.

        This URL is unique and publicly signed for a short time, so make sure to upload
        your files in a timely manner.

        **Example flow using JavaScript and the Fetch API:**

        **Request an upload URL**

        ```js
        // Step 1: Request an upload URL from your API
        const response = await fetch(
          "https://api.postforme.dev/v1/media/create-upload-url",
          {
            method: "POST",
            headers: {
              "Content-Type": "application/json",
            },
          }
        );

        const { media_url, upload_url } = await response.json();
        ```

        **Upload your file to the signed URL**

        ```js
        // Step 2: Upload your file to the signed URL
        const file = /* your File or Blob object, e.g., from an <input type="file"> */;
        await fetch(upload_url, {
          method: 'PUT',
          headers: {
            'Content-Type': 'image/jpeg'
          },
          body: file
        });
        ```

        **Use the `media_url` when creating your post**

            ```js
            // Step 3: Use the `media_url` when creating your post
            const response = await fetch('https://api.postforme.dev/v1/social-posts', {
              method: 'POST',
              headers: {
                'Content-Type': 'application/json'
              },
              body: JSON.stringify({
                social_accounts: ['spc_...', ...],
                caption: 'My caption',
                media: [
                  {
                    url: media_url
                  }
                ]
              })
            });
            ```
        """
        return self._post(
            "/v1/media/create-upload-url",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=MediaCreateUploadURLResponse,
        )


class AsyncMediaResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncMediaResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/DayMoonDevelopment/post-for-me-python#accessing-raw-response-data-eg-headers
        """
        return AsyncMediaResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncMediaResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/DayMoonDevelopment/post-for-me-python#with_streaming_response
        """
        return AsyncMediaResourceWithStreamingResponse(self)

    async def create_upload_url(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> MediaCreateUploadURLResponse:
        """
        To upload media to attach to your post, make a `POST` request to the
        `/media/create-upload-url` endpoint.

        You'll receive the public url of your media item (which can be used when making
        a post) and will include an `upload_url` which is a signed URL of the storage
        location for uploading your file to.

        This URL is unique and publicly signed for a short time, so make sure to upload
        your files in a timely manner.

        **Example flow using JavaScript and the Fetch API:**

        **Request an upload URL**

        ```js
        // Step 1: Request an upload URL from your API
        const response = await fetch(
          "https://api.postforme.dev/v1/media/create-upload-url",
          {
            method: "POST",
            headers: {
              "Content-Type": "application/json",
            },
          }
        );

        const { media_url, upload_url } = await response.json();
        ```

        **Upload your file to the signed URL**

        ```js
        // Step 2: Upload your file to the signed URL
        const file = /* your File or Blob object, e.g., from an <input type="file"> */;
        await fetch(upload_url, {
          method: 'PUT',
          headers: {
            'Content-Type': 'image/jpeg'
          },
          body: file
        });
        ```

        **Use the `media_url` when creating your post**

            ```js
            // Step 3: Use the `media_url` when creating your post
            const response = await fetch('https://api.postforme.dev/v1/social-posts', {
              method: 'POST',
              headers: {
                'Content-Type': 'application/json'
              },
              body: JSON.stringify({
                social_accounts: ['spc_...', ...],
                caption: 'My caption',
                media: [
                  {
                    url: media_url
                  }
                ]
              })
            });
            ```
        """
        return await self._post(
            "/v1/media/create-upload-url",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=MediaCreateUploadURLResponse,
        )


class MediaResourceWithRawResponse:
    def __init__(self, media: MediaResource) -> None:
        self._media = media

        self.create_upload_url = to_raw_response_wrapper(
            media.create_upload_url,
        )


class AsyncMediaResourceWithRawResponse:
    def __init__(self, media: AsyncMediaResource) -> None:
        self._media = media

        self.create_upload_url = async_to_raw_response_wrapper(
            media.create_upload_url,
        )


class MediaResourceWithStreamingResponse:
    def __init__(self, media: MediaResource) -> None:
        self._media = media

        self.create_upload_url = to_streamed_response_wrapper(
            media.create_upload_url,
        )


class AsyncMediaResourceWithStreamingResponse:
    def __init__(self, media: AsyncMediaResource) -> None:
        self._media = media

        self.create_upload_url = async_to_streamed_response_wrapper(
            media.create_upload_url,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Iterable, Optional
from typing_extensions import Literal, Required, TypedDict

__all__ = ["TiktokConfigurationParam", "Media", "MediaTag"]


class MediaTag(TypedDict, total=False):
    id: Required[str]
    """Facebook User ID, Instagram Username or Instagram product id to tag"""

    platform: Required[Literal["facebook", "instagram"]]
    """The platform for the tags"""

    type: Required[Literal["user", "product"]]
    """
    The type of tag, user to tag accounts, product to tag products (only supported
    for instagram)
    """

    x: float
    """
    Percentage distance from left edge of the image, Not required for videos or
    stories
    """

    y: float
    """
    Percentage distance from top edge of the image, Not required for videos or
    stories
    """


class Media(TypedDict, total=False):
    url: Required[str]
    """Public URL of the media"""

    tags: Optional[Iterable[MediaTag]]
    """List of tags to attach to the media"""

    thumbnail_timestamp_ms: Optional[object]
    """Timestamp in milliseconds of frame to use as thumbnail for the media"""

    thumbnail_url: Optional[object]
    """Public URL of the thumbnail for the media"""


class TiktokConfigurationParam(TypedDict, total=False):
    allow_comment: Optional[bool]
    """Allow comments on TikTok"""

    allow_duet: Optional[bool]
    """Allow duets on TikTok"""

    allow_stitch: Optional[bool]
    """Allow stitch on TikTok"""

    auto_add_music: Optional[bool]
    """Will automatically add music to photo posts"""

    caption: Optional[object]
    """Overrides the `caption` from the post"""

    disclose_branded_content: Optional[bool]
    """Disclose branded content on TikTok"""

    disclose_your_brand: Optional[bool]
    """Disclose your brand on TikTok"""

    is_ai_generated: Optional[bool]
    """Flag content as AI generated on TikTok"""

    is_draft: Optional[bool]
    """
    Will create a draft upload to TikTok, posting will need to be completed from
    within the app
    """

    media: Optional[Iterable[Media]]
    """Overrides the `media` from the post"""

    privacy_status: Optional[str]
    """Sets the privacy status for TikTok (private, public)"""

    title: Optional[str]
    """Overrides the `title` from the post"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from .._models import BaseModel
from .platform_post import PlatformPost

__all__ = ["SocialAccountFeedListResponse", "Meta"]


class Meta(BaseModel):
    cursor: str
    """Id representing the next page of items"""

    limit: float
    """Maximum number of items returned."""

    next: Optional[str] = None
    """URL to the next page of results, or null if none."""

    has_more: Optional[bool] = None
    """Indicates if there are more results or not"""


class SocialAccountFeedListResponse(BaseModel):
    data: List[PlatformPost]

    meta: Meta



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Iterable, Optional
from typing_extensions import Literal, Required, TypedDict

from .._types import SequenceNotStr

__all__ = ["InstagramConfigurationDtoParam", "Media", "MediaTag"]


class MediaTag(TypedDict, total=False):
    id: Required[str]
    """Facebook User ID, Instagram Username or Instagram product id to tag"""

    platform: Required[Literal["facebook", "instagram"]]
    """The platform for the tags"""

    type: Required[Literal["user", "product"]]
    """
    The type of tag, user to tag accounts, product to tag products (only supported
    for instagram)
    """

    x: float
    """
    Percentage distance from left edge of the image, Not required for videos or
    stories
    """

    y: float
    """
    Percentage distance from top edge of the image, Not required for videos or
    stories
    """


class Media(TypedDict, total=False):
    url: Required[str]
    """Public URL of the media"""

    tags: Optional[Iterable[MediaTag]]
    """List of tags to attach to the media"""

    thumbnail_timestamp_ms: Optional[object]
    """Timestamp in milliseconds of frame to use as thumbnail for the media"""

    thumbnail_url: Optional[object]
    """Public URL of the thumbnail for the media"""


class InstagramConfigurationDtoParam(TypedDict, total=False):
    caption: Optional[object]
    """Overrides the `caption` from the post"""

    collaborators: Optional[SequenceNotStr[str]]
    """Instagram usernames to be tagged as a collaborator"""

    location: Optional[str]
    """Page id with a location that you want to tag the image or video with"""

    media: Optional[Iterable[Media]]
    """Overrides the `media` from the post"""

    placement: Optional[Literal["reels", "stories", "timeline"]]
    """Instagram post placement"""

    share_to_feed: Optional[bool]
    """If false video posts will only be shown in the Reels tab"""

    trial_reel_type: Optional[Literal["manual", "performance"]]
    """Instagram trial reel type, when passed will be created as a trial reel.

    If manual the trial reel can be manually graduated in the native app. If
    perfomance the trial reel will be automatically graduated if the trial reel
    performs well.
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Union, Iterable, Optional
from datetime import datetime
from typing_extensions import Literal, Required, Annotated, TypedDict

from .._types import SequenceNotStr
from .._utils import PropertyInfo
from .platform_configurations_dto_param import PlatformConfigurationsDtoParam

__all__ = [
    "SocialPostUpdateParams",
    "AccountConfiguration",
    "AccountConfigurationConfiguration",
    "AccountConfigurationConfigurationMedia",
    "AccountConfigurationConfigurationMediaTag",
    "AccountConfigurationConfigurationPoll",
    "Media",
    "MediaTag",
]


class SocialPostUpdateParams(TypedDict, total=False):
    caption: Required[str]
    """Caption text for the post"""

    social_accounts: Required[SequenceNotStr[str]]
    """Array of social account IDs for posting"""

    account_configurations: Optional[Iterable[AccountConfiguration]]
    """Account-specific configurations for the post"""

    external_id: Optional[str]
    """Array of social account IDs for posting"""

    is_draft: Annotated[Optional[bool], PropertyInfo(alias="isDraft")]
    """If isDraft is set then the post will not be processed"""

    media: Optional[Iterable[Media]]
    """Array of media URLs associated with the post"""

    platform_configurations: Optional[PlatformConfigurationsDtoParam]
    """Platform-specific configurations for the post"""

    scheduled_at: Annotated[Union[str, datetime, None], PropertyInfo(format="iso8601")]
    """
    Scheduled date and time for the post, setting to null or undefined will post
    instantly
    """


class AccountConfigurationConfigurationMediaTag(TypedDict, total=False):
    id: Required[str]
    """Facebook User ID, Instagram Username or Instagram product id to tag"""

    platform: Required[Literal["facebook", "instagram"]]
    """The platform for the tags"""

    type: Required[Literal["user", "product"]]
    """
    The type of tag, user to tag accounts, product to tag products (only supported
    for instagram)
    """

    x: float
    """
    Percentage distance from left edge of the image, Not required for videos or
    stories
    """

    y: float
    """
    Percentage distance from top edge of the image, Not required for videos or
    stories
    """


class AccountConfigurationConfigurationMedia(TypedDict, total=False):
    url: Required[str]
    """Public URL of the media"""

    tags: Optional[Iterable[AccountConfigurationConfigurationMediaTag]]
    """List of tags to attach to the media"""

    thumbnail_timestamp_ms: Optional[object]
    """Timestamp in milliseconds of frame to use as thumbnail for the media"""

    thumbnail_url: Optional[object]
    """Public URL of the thumbnail for the media"""


class AccountConfigurationConfigurationPoll(TypedDict, total=False):
    """Poll options for the twitter"""

    duration_minutes: Required[float]
    """Duration of the poll in minutes"""

    options: Required[SequenceNotStr[str]]
    """The choices of the poll, requiring 2-4 options"""

    reply_settings: Literal["following", "mentionedUsers", "subscribers", "verified"]
    """Who can reply to the tweet"""


class AccountConfigurationConfiguration(TypedDict, total=False):
    """Configuration for the social account"""

    allow_comment: Optional[bool]
    """Allow comments on TikTok"""

    allow_duet: Optional[bool]
    """Allow duets on TikTok"""

    allow_stitch: Optional[bool]
    """Allow stitch on TikTok"""

    auto_add_music: Optional[bool]
    """Will automatically add music to photo posts on TikTok"""

    board_ids: Optional[SequenceNotStr[str]]
    """Pinterest board IDs"""

    caption: Optional[object]
    """Overrides the `caption` from the post"""

    collaborators: Optional[Iterable[Iterable[object]]]
    """
    List of page ids or users to invite as collaborators for a Video Reel (Instagram
    and Facebook)
    """

    community_id: str
    """Id of the twitter community to post to"""

    disclose_branded_content: Optional[bool]
    """Disclose branded content on TikTok"""

    disclose_your_brand: Optional[bool]
    """Disclose your brand on TikTok"""

    is_ai_generated: Optional[bool]
    """Flag content as AI generated on TikTok"""

    is_draft: Optional[bool]
    """
    Will create a draft upload to TikTok, posting will need to be completed from
    within the app
    """

    link: Optional[str]
    """Pinterest post link"""

    location: Optional[str]
    """
    Page id with a location that you want to tag the image or video with (Instagram
    and Facebook)
    """

    made_for_kids: Optional[bool]
    """If true will notify YouTube the video is intended for kids, defaults to false"""

    media: Optional[Iterable[AccountConfigurationConfigurationMedia]]
    """Overrides the `media` from the post"""

    placement: Optional[Literal["reels", "timeline", "stories"]]
    """Post placement for Facebook/Instagram/Threads"""

    poll: AccountConfigurationConfigurationPoll
    """Poll options for the twitter"""

    privacy_status: Optional[Literal["public", "private", "unlisted"]]
    """
    Sets the privacy status for TikTok (private, public), or YouTube (private,
    public, unlisted)
    """

    quote_tweet_id: str
    """Id of the tweet you want to quote"""

    reply_settings: Optional[Literal["following", "mentionedUsers", "subscribers", "verified"]]
    """Who can reply to the tweet"""

    share_to_feed: Optional[bool]
    """If false Instagram video posts will only be shown in the Reels tab"""

    title: Optional[str]
    """Overrides the `title` from the post"""

    trial_reel_type: Optional[Literal["manual", "performance"]]
    """Instagram trial reel type, when passed will be created as a trial reel.

    If manual the trial reel can be manually graduated in the native app. If
    perfomance the trial reel will be automatically graduated if the trial reel
    performs well.
    """


class AccountConfiguration(TypedDict, total=False):
    configuration: Required[AccountConfigurationConfiguration]
    """Configuration for the social account"""

    social_account_id: Required[str]
    """ID of the social account, you want to apply the configuration to"""


class MediaTag(TypedDict, total=False):
    id: Required[str]
    """Facebook User ID, Instagram Username or Instagram product id to tag"""

    platform: Required[Literal["facebook", "instagram"]]
    """The platform for the tags"""

    type: Required[Literal["user", "product"]]
    """
    The type of tag, user to tag accounts, product to tag products (only supported
    for instagram)
    """

    x: float
    """
    Percentage distance from left edge of the image, Not required for videos or
    stories
    """

    y: float
    """
    Percentage distance from top edge of the image, Not required for videos or
    stories
    """


class Media(TypedDict, total=False):
    url: Required[str]
    """Public URL of the media"""

    tags: Optional[Iterable[MediaTag]]
    """List of tags to attach to the media"""

    thumbnail_timestamp_ms: Optional[object]
    """Timestamp in milliseconds of frame to use as thumbnail for the media"""

    thumbnail_url: Optional[object]
    """Public URL of the thumbnail for the media"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .._models import BaseModel

__all__ = ["SocialAccountCreateAuthURLResponse"]


class SocialAccountCreateAuthURLResponse(BaseModel):
    platform: str
    """The social account provider"""

    url: str
    """The url to redirect the user to, in order to connect their account"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from post_for_me import PostForMe, AsyncPostForMe
from tests.utils import assert_matches_type
from post_for_me.types import (
    SocialPost,
    SocialPostListResponse,
    SocialPostDeleteResponse,
)
from post_for_me._utils import parse_datetime

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestSocialPosts:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_create(self, client: PostForMe) -> None:
        social_post = client.social_posts.create(
            caption="caption",
            social_accounts=["string"],
        )
        assert_matches_type(SocialPost, social_post, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_create_with_all_params(self, client: PostForMe) -> None:
        social_post = client.social_posts.create(
            caption="caption",
            social_accounts=["string"],
            account_configurations=[
                {
                    "configuration": {
                        "allow_comment": True,
                        "allow_duet": True,
                        "allow_stitch": True,
                        "auto_add_music": True,
                        "board_ids": ["string"],
                        "caption": {},
                        "collaborators": [[{}]],
                        "community_id": "community_id",
                        "disclose_branded_content": True,
                        "disclose_your_brand": True,
                        "is_ai_generated": True,
                        "is_draft": True,
                        "link": "link",
                        "location": "location",
                        "made_for_kids": True,
                        "media": [
                            {
                                "url": "url",
                                "tags": [
                                    {
                                        "id": "id",
                                        "platform": "facebook",
                                        "type": "user",
                                        "x": 0,
                                        "y": 0,
                                    }
                                ],
                                "thumbnail_timestamp_ms": {},
                                "thumbnail_url": {},
                            }
                        ],
                        "placement": "reels",
                        "poll": {
                            "duration_minutes": 0,
                            "options": ["string"],
                            "reply_settings": "following",
                        },
                        "privacy_status": "public",
                        "quote_tweet_id": "quote_tweet_id",
                        "reply_settings": "following",
                        "share_to_feed": True,
                        "title": "title",
                        "trial_reel_type": "manual",
                    },
                    "social_account_id": "social_account_id",
                }
            ],
            external_id="external_id",
            is_draft=True,
            media=[
                {
                    "url": "url",
                    "tags": [
                        {
                            "id": "id",
                            "platform": "facebook",
                            "type": "user",
                            "x": 0,
                            "y": 0,
                        }
                    ],
                    "thumbnail_timestamp_ms": {},
                    "thumbnail_url": {},
                }
            ],
            platform_configurations={
                "bluesky": {
                    "caption": {},
                    "media": [
                        {
                            "url": "url",
                            "tags": [
                                {
                                    "id": "id",
                                    "platform": "facebook",
                                    "type": "user",
                                    "x": 0,
                                    "y": 0,
                                }
                            ],
                            "thumbnail_timestamp_ms": {},
                            "thumbnail_url": {},
                        }
                    ],
                },
                "facebook": {
                    "caption": {},
                    "collaborators": [[{}]],
                    "location": "location",
                    "media": [
                        {
                            "url": "url",
                            "tags": [
                                {
                                    "id": "id",
                                    "platform": "facebook",
                                    "type": "user",
                                    "x": 0,
                                    "y": 0,
                                }
                            ],
                            "thumbnail_timestamp_ms": {},
                            "thumbnail_url": {},
                        }
                    ],
                    "placement": "reels",
                },
                "instagram": {
                    "caption": {},
                    "collaborators": ["string"],
                    "location": "location",
                    "media": [
                        {
                            "url": "url",
                            "tags": [
                                {
                                    "id": "id",
                                    "platform": "facebook",
                                    "type": "user",
                                    "x": 0,
                                    "y": 0,
                                }
                            ],
                            "thumbnail_timestamp_ms": {},
                            "thumbnail_url": {},
                        }
                    ],
                    "placement": "reels",
                    "share_to_feed": True,
                    "trial_reel_type": "manual",
                },
                "linkedin": {
                    "caption": {},
                    "media": [
                        {
                            "url": "url",
                            "tags": [
                                {
                                    "id": "id",
                                    "platform": "facebook",
                                    "type": "user",
                                    "x": 0,
                                    "y": 0,
                                }
                            ],
                            "thumbnail_timestamp_ms": {},
                            "thumbnail_url": {},
                        }
                    ],
                },
                "pinterest": {
                    "board_ids": ["string"],
                    "caption": {},
                    "link": "link",
                    "media": [
                        {
                            "url": "url",
                            "tags": [
                                {
                                    "id": "id",
                                    "platform": "facebook",
                                    "type": "user",
                                    "x": 0,
                                    "y": 0,
                                }
                            ],
                            "thumbnail_timestamp_ms": {},
                            "thumbnail_url": {},
                        }
                    ],
                },
                "threads": {
                    "caption": {},
                    "media": [
                        {
                            "url": "url",
                            "tags": [
                                {
                                    "id": "id",
                                    "platform": "facebook",
                                    "type": "user",
                                    "x": 0,
                                    "y": 0,
                                }
                            ],
                            "thumbnail_timestamp_ms": {},
                            "thumbnail_url": {},
                        }
                    ],
                    "placement": "reels",
                },
                "tiktok": {
                    "allow_comment": True,
                    "allow_duet": True,
                    "allow_stitch": True,
                    "auto_add_music": True,
                    "caption": {},
                    "disclose_branded_content": True,
                    "disclose_your_brand": True,
                    "is_ai_generated": True,
                    "is_draft": True,
                    "media": [
                        {
                            "url": "url",
                            "tags": [
                                {
                                    "id": "id",
                                    "platform": "facebook",
                                    "type": "user",
                                    "x": 0,
                                    "y": 0,
                                }
                            ],
                            "thumbnail_timestamp_ms": {},
                            "thumbnail_url": {},
                        }
                    ],
                    "privacy_status": "privacy_status",
                    "title": "title",
                },
                "tiktok_business": {
                    "allow_comment": True,
                    "allow_duet": True,
                    "allow_stitch": True,
                    "auto_add_music": True,
                    "caption": {},
                    "disclose_branded_content": True,
                    "disclose_your_brand": True,
                    "is_ai_generated": True,
                    "is_draft": True,
                    "media": [
                        {
                            "url": "url",
                            "tags": [
                                {
                                    "id": "id",
                                    "platform": "facebook",
                                    "type": "user",
                                    "x": 0,
                                    "y": 0,
                                }
                            ],
                            "thumbnail_timestamp_ms": {},
                            "thumbnail_url": {},
                        }
                    ],
                    "privacy_status": "privacy_status",
                    "title": "title",
                },
                "x": {
                    "caption": {},
                    "community_id": "community_id",
                    "media": [
                        {
                            "url": "url",
                            "tags": [
                                {
                                    "id": "id",
                                    "platform": "facebook",
                                    "type": "user",
                                    "x": 0,
                                    "y": 0,
                                }
                            ],
                            "thumbnail_timestamp_ms": {},
                            "thumbnail_url": {},
                        }
                    ],
                    "poll": {
                        "duration_minutes": 0,
                        "options": ["string"],
                        "reply_settings": "following",
                    },
                    "quote_tweet_id": "quote_tweet_id",
                    "reply_settings": "following",
                },
                "youtube": {
                    "caption": {},
                    "made_for_kids": True,
                    "media": [
                        {
                            "url": "url",
                            "tags": [
                                {
                                    "id": "id",
                                    "platform": "facebook",
                                    "type": "user",
                                    "x": 0,
                                    "y": 0,
                                }
                            ],
                            "thumbnail_timestamp_ms": {},
                            "thumbnail_url": {},
                        }
                    ],
                    "privacy_status": "public",
                    "title": "title",
                },
            },
            scheduled_at=parse_datetime("2019-12-27T18:11:19.117Z"),
        )
        assert_matches_type(SocialPost, social_post, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_create(self, client: PostForMe) -> None:
        response = client.social_posts.with_raw_response.create(
            caption="caption",
            social_accounts=["string"],
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        social_post = response.parse()
        assert_matches_type(SocialPost, social_post, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_create(self, client: PostForMe) -> None:
        with client.social_posts.with_streaming_response.create(
            caption="caption",
            social_accounts=["string"],
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            social_post = response.parse()
            assert_matches_type(SocialPost, social_post, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_retrieve(self, client: PostForMe) -> None:
        social_post = client.social_posts.retrieve(
            "id",
        )
        assert_matches_type(SocialPost, social_post, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_retrieve(self, client: PostForMe) -> None:
        response = client.social_posts.with_raw_response.retrieve(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        social_post = response.parse()
        assert_matches_type(SocialPost, social_post, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_retrieve(self, client: PostForMe) -> None:
        with client.social_posts.with_streaming_response.retrieve(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            social_post = response.parse()
            assert_matches_type(SocialPost, social_post, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_retrieve(self, client: PostForMe) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.social_posts.with_raw_response.retrieve(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_update(self, client: PostForMe) -> None:
        social_post = client.social_posts.update(
            id="id",
            caption="caption",
            social_accounts=["string"],
        )
        assert_matches_type(SocialPost, social_post, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_update_with_all_params(self, client: PostForMe) -> None:
        social_post = client.social_posts.update(
            id="id",
            caption="caption",
            social_accounts=["string"],
            account_configurations=[
                {
                    "configuration": {
                        "allow_comment": True,
                        "allow_duet": True,
                        "allow_stitch": True,
                        "auto_add_music": True,
                        "board_ids": ["string"],
                        "caption": {},
                        "collaborators": [[{}]],
                        "community_id": "community_id",
                        "disclose_branded_content": True,
                        "disclose_your_brand": True,
                        "is_ai_generated": True,
                        "is_draft": True,
                        "link": "link",
                        "location": "location",
                        "made_for_kids": True,
                        "media": [
                            {
                                "url": "url",
                                "tags": [
                                    {
                                        "id": "id",
                                        "platform": "facebook",
                                        "type": "user",
                                        "x": 0,
                                        "y": 0,
                                    }
                                ],
                                "thumbnail_timestamp_ms": {},
                                "thumbnail_url": {},
                            }
                        ],
                        "placement": "reels",
                        "poll": {
                            "duration_minutes": 0,
                            "options": ["string"],
                            "reply_settings": "following",
                        },
                        "privacy_status": "public",
                        "quote_tweet_id": "quote_tweet_id",
                        "reply_settings": "following",
                        "share_to_feed": True,
                        "title": "title",
                        "trial_reel_type": "manual",
                    },
                    "social_account_id": "social_account_id",
                }
            ],
            external_id="external_id",
            is_draft=True,
            media=[
                {
                    "url": "url",
                    "tags": [
                        {
                            "id": "id",
                            "platform": "facebook",
                            "type": "user",
                            "x": 0,
                            "y": 0,
                        }
                    ],
                    "thumbnail_timestamp_ms": {},
                    "thumbnail_url": {},
                }
            ],
            platform_configurations={
                "bluesky": {
                    "caption": {},
                    "media": [
                        {
                            "url": "url",
                            "tags": [
                                {
                                    "id": "id",
                                    "platform": "facebook",
                                    "type": "user",
                                    "x": 0,
                                    "y": 0,
                                }
                            ],
                            "thumbnail_timestamp_ms": {},
                            "thumbnail_url": {},
                        }
                    ],
                },
                "facebook": {
                    "caption": {},
                    "collaborators": [[{}]],
                    "location": "location",
                    "media": [
                        {
                            "url": "url",
                            "tags": [
                                {
                                    "id": "id",
                                    "platform": "facebook",
                                    "type": "user",
                                    "x": 0,
                                    "y": 0,
                                }
                            ],
                            "thumbnail_timestamp_ms": {},
                            "thumbnail_url": {},
                        }
                    ],
                    "placement": "reels",
                },
                "instagram": {
                    "caption": {},
                    "collaborators": ["string"],
                    "location": "location",
                    "media": [
                        {
                            "url": "url",
                            "tags": [
                                {
                                    "id": "id",
                                    "platform": "facebook",
                                    "type": "user",
                                    "x": 0,
                                    "y": 0,
                                }
                            ],
                            "thumbnail_timestamp_ms": {},
                            "thumbnail_url": {},
                        }
                    ],
                    "placement": "reels",
                    "share_to_feed": True,
                    "trial_reel_type": "manual",
                },
                "linkedin": {
                    "caption": {},
                    "media": [
                        {
                            "url": "url",
                            "tags": [
                                {
                                    "id": "id",
                                    "platform": "facebook",
                                    "type": "user",
                                    "x": 0,
                                    "y": 0,
                                }
                            ],
                            "thumbnail_timestamp_ms": {},
                            "thumbnail_url": {},
                        }
                    ],
                },
                "pinterest": {
                    "board_ids": ["string"],
                    "caption": {},
                    "link": "link",
                    "media": [
                        {
                            "url": "url",
                            "tags": [
                                {
                                    "id": "id",
                                    "platform": "facebook",
                                    "type": "user",
                                    "x": 0,
                                    "y": 0,
                                }
                            ],
                            "thumbnail_timestamp_ms": {},
                            "thumbnail_url": {},
                        }
                    ],
                },
                "threads": {
                    "caption": {},
                    "media": [
                        {
                            "url": "url",
                            "tags": [
                                {
                                    "id": "id",
                                    "platform": "facebook",
                                    "type": "user",
                                    "x": 0,
                                    "y": 0,
                                }
                            ],
                            "thumbnail_timestamp_ms": {},
                            "thumbnail_url": {},
                        }
                    ],
                    "placement": "reels",
                },
                "tiktok": {
                    "allow_comment": True,
                    "allow_duet": True,
                    "allow_stitch": True,
                    "auto_add_music": True,
                    "caption": {},
                    "disclose_branded_content": True,
                    "disclose_your_brand": True,
                    "is_ai_generated": True,
                    "is_draft": True,
                    "media": [
                        {
                            "url": "url",
                            "tags": [
                                {
                                    "id": "id",
                                    "platform": "facebook",
                                    "type": "user",
                                    "x": 0,
                                    "y": 0,
                                }
                            ],
                            "thumbnail_timestamp_ms": {},
                            "thumbnail_url": {},
                        }
                    ],
                    "privacy_status": "privacy_status",
                    "title": "title",
                },
                "tiktok_business": {
                    "allow_comment": True,
                    "allow_duet": True,
                    "allow_stitch": True,
                    "auto_add_music": True,
                    "caption": {},
                    "disclose_branded_content": True,
                    "disclose_your_brand": True,
                    "is_ai_generated": True,
                    "is_draft": True,
                    "media": [
                        {
                            "url": "url",
                            "tags": [
                                {
                                    "id": "id",
                                    "platform": "facebook",
                                    "type": "user",
                                    "x": 0,
                                    "y": 0,
                                }
                            ],
                            "thumbnail_timestamp_ms": {},
                            "thumbnail_url": {},
                        }
                    ],
                    "privacy_status": "privacy_status",
                    "title": "title",
                },
                "x": {
                    "caption": {},
                    "community_id": "community_id",
                    "media": [
                        {
                            "url": "url",
                            "tags": [
                                {
                                    "id": "id",
                                    "platform": "facebook",
                                    "type": "user",
                                    "x": 0,
                                    "y": 0,
                                }
                            ],
                            "thumbnail_timestamp_ms": {},
                            "thumbnail_url": {},
                        }
                    ],
                    "poll": {
                        "duration_minutes": 0,
                        "options": ["string"],
                        "reply_settings": "following",
                    },
                    "quote_tweet_id": "quote_tweet_id",
                    "reply_settings": "following",
                },
                "youtube": {
                    "caption": {},
                    "made_for_kids": True,
                    "media": [
                        {
                            "url": "url",
                            "tags": [
                                {
                                    "id": "id",
                                    "platform": "facebook",
                                    "type": "user",
                                    "x": 0,
                                    "y": 0,
                                }
                            ],
                            "thumbnail_timestamp_ms": {},
                            "thumbnail_url": {},
                        }
                    ],
                    "privacy_status": "public",
                    "title": "title",
                },
            },
            scheduled_at=parse_datetime("2019-12-27T18:11:19.117Z"),
        )
        assert_matches_type(SocialPost, social_post, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_update(self, client: PostForMe) -> None:
        response = client.social_posts.with_raw_response.update(
            id="id",
            caption="caption",
            social_accounts=["string"],
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        social_post = response.parse()
        assert_matches_type(SocialPost, social_post, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_update(self, client: PostForMe) -> None:
        with client.social_posts.with_streaming_response.update(
            id="id",
            caption="caption",
            social_accounts=["string"],
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            social_post = response.parse()
            assert_matches_type(SocialPost, social_post, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_update(self, client: PostForMe) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.social_posts.with_raw_response.update(
                id="",
                caption="caption",
                social_accounts=["string"],
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_list(self, client: PostForMe) -> None:
        social_post = client.social_posts.list()
        assert_matches_type(SocialPostListResponse, social_post, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_list_with_all_params(self, client: PostForMe) -> None:
        social_post = client.social_posts.list(
            external_id=["string"],
            limit=0,
            offset=0,
            platform=["bluesky"],
            social_account_id=["string"],
            status=["draft"],
        )
        assert_matches_type(SocialPostListResponse, social_post, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_list(self, client: PostForMe) -> None:
        response = client.social_posts.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        social_post = response.parse()
        assert_matches_type(SocialPostListResponse, social_post, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_list(self, client: PostForMe) -> None:
        with client.social_posts.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            social_post = response.parse()
            assert_matches_type(SocialPostListResponse, social_post, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_delete(self, client: PostForMe) -> None:
        social_post = client.social_posts.delete(
            "id",
        )
        assert_matches_type(SocialPostDeleteResponse, social_post, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_delete(self, client: PostForMe) -> None:
        response = client.social_posts.with_raw_response.delete(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        social_post = response.parse()
        assert_matches_type(SocialPostDeleteResponse, social_post, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_delete(self, client: PostForMe) -> None:
        with client.social_posts.with_streaming_response.delete(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            social_post = response.parse()
            assert_matches_type(SocialPostDeleteResponse, social_post, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_delete(self, client: PostForMe) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.social_posts.with_raw_response.delete(
                "",
            )


class TestAsyncSocialPosts:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_create(self, async_client: AsyncPostForMe) -> None:
        social_post = await async_client.social_posts.create(
            caption="caption",
            social_accounts=["string"],
        )
        assert_matches_type(SocialPost, social_post, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_create_with_all_params(self, async_client: AsyncPostForMe) -> None:
        social_post = await async_client.social_posts.create(
            caption="caption",
            social_accounts=["string"],
            account_configurations=[
                {
                    "configuration": {
                        "allow_comment": True,
                        "allow_duet": True,
                        "allow_stitch": True,
                        "auto_add_music": True,
                        "board_ids": ["string"],
                        "caption": {},
                        "collaborators": [[{}]],
                        "community_id": "community_id",
                        "disclose_branded_content": True,
                        "disclose_your_brand": True,
                        "is_ai_generated": True,
                        "is_draft": True,
                        "link": "link",
                        "location": "location",
                        "made_for_kids": True,
                        "media": [
                            {
                                "url": "url",
                                "tags": [
                                    {
                                        "id": "id",
                                        "platform": "facebook",
                                        "type": "user",
                                        "x": 0,
                                        "y": 0,
                                    }
                                ],
                                "thumbnail_timestamp_ms": {},
                                "thumbnail_url": {},
                            }
                        ],
                        "placement": "reels",
                        "poll": {
                            "duration_minutes": 0,
                            "options": ["string"],
                            "reply_settings": "following",
                        },
                        "privacy_status": "public",
                        "quote_tweet_id": "quote_tweet_id",
                        "reply_settings": "following",
                        "share_to_feed": True,
                        "title": "title",
                        "trial_reel_type": "manual",
                    },
                    "social_account_id": "social_account_id",
                }
            ],
            external_id="external_id",
            is_draft=True,
            media=[
                {
                    "url": "url",
                    "tags": [
                        {
                            "id": "id",
                            "platform": "facebook",
                            "type": "user",
                            "x": 0,
                            "y": 0,
                        }
                    ],
                    "thumbnail_timestamp_ms": {},
                    "thumbnail_url": {},
                }
            ],
            platform_configurations={
                "bluesky": {
                    "caption": {},
                    "media": [
                        {
                            "url": "url",
                            "tags": [
                                {
                                    "id": "id",
                                    "platform": "facebook",
                                    "type": "user",
                                    "x": 0,
                                    "y": 0,
                                }
                            ],
                            "thumbnail_timestamp_ms": {},
                            "thumbnail_url": {},
                        }
                    ],
                },
                "facebook": {
                    "caption": {},
                    "collaborators": [[{}]],
                    "location": "location",
                    "media": [
                        {
                            "url": "url",
                            "tags": [
                                {
                                    "id": "id",
                                    "platform": "facebook",
                                    "type": "user",
                                    "x": 0,
                                    "y": 0,
                                }
                            ],
                            "thumbnail_timestamp_ms": {},
                            "thumbnail_url": {},
                        }
                    ],
                    "placement": "reels",
                },
                "instagram": {
                    "caption": {},
                    "collaborators": ["string"],
                    "location": "location",
                    "media": [
                        {
                            "url": "url",
                            "tags": [
                                {
                                    "id": "id",
                                    "platform": "facebook",
                                    "type": "user",
                                    "x": 0,
                                    "y": 0,
                                }
                            ],
                            "thumbnail_timestamp_ms": {},
                            "thumbnail_url": {},
                        }
                    ],
                    "placement": "reels",
                    "share_to_feed": True,
                    "trial_reel_type": "manual",
                },
                "linkedin": {
                    "caption": {},
                    "media": [
                        {
                            "url": "url",
                            "tags": [
                                {
                                    "id": "id",
                                    "platform": "facebook",
                                    "type": "user",
                                    "x": 0,
                                    "y": 0,
                                }
                            ],
                            "thumbnail_timestamp_ms": {},
                            "thumbnail_url": {},
                        }
                    ],
                },
                "pinterest": {
                    "board_ids": ["string"],
                    "caption": {},
                    "link": "link",
                    "media": [
                        {
                            "url": "url",
                            "tags": [
                                {
                                    "id": "id",
                                    "platform": "facebook",
                                    "type": "user",
                                    "x": 0,
                                    "y": 0,
                                }
                            ],
                            "thumbnail_timestamp_ms": {},
                            "thumbnail_url": {},
                        }
                    ],
                },
                "threads": {
                    "caption": {},
                    "media": [
                        {
                            "url": "url",
                            "tags": [
                                {
                                    "id": "id",
                                    "platform": "facebook",
                                    "type": "user",
                                    "x": 0,
                                    "y": 0,
                                }
                            ],
                            "thumbnail_timestamp_ms": {},
                            "thumbnail_url": {},
                        }
                    ],
                    "placement": "reels",
                },
                "tiktok": {
                    "allow_comment": True,
                    "allow_duet": True,
                    "allow_stitch": True,
                    "auto_add_music": True,
                    "caption": {},
                    "disclose_branded_content": True,
                    "disclose_your_brand": True,
                    "is_ai_generated": True,
                    "is_draft": True,
                    "media": [
                        {
                            "url": "url",
                            "tags": [
                                {
                                    "id": "id",
                                    "platform": "facebook",
                                    "type": "user",
                                    "x": 0,
                                    "y": 0,
                                }
                            ],
                            "thumbnail_timestamp_ms": {},
                            "thumbnail_url": {},
                        }
                    ],
                    "privacy_status": "privacy_status",
                    "title": "title",
                },
                "tiktok_business": {
                    "allow_comment": True,
                    "allow_duet": True,
                    "allow_stitch": True,
                    "auto_add_music": True,
                    "caption": {},
                    "disclose_branded_content": True,
                    "disclose_your_brand": True,
                    "is_ai_generated": True,
                    "is_draft": True,
                    "media": [
                        {
                            "url": "url",
                            "tags": [
                                {
                                    "id": "id",
                                    "platform": "facebook",
                                    "type": "user",
                                    "x": 0,
                                    "y": 0,
                                }
                            ],
                            "thumbnail_timestamp_ms": {},
                            "thumbnail_url": {},
                        }
                    ],
                    "privacy_status": "privacy_status",
                    "title": "title",
                },
                "x": {
                    "caption": {},
                    "community_id": "community_id",
                    "media": [
                        {
                            "url": "url",
                            "tags": [
                                {
                                    "id": "id",
                                    "platform": "facebook",
                                    "type": "user",
                                    "x": 0,
                                    "y": 0,
                                }
                            ],
                            "thumbnail_timestamp_ms": {},
                            "thumbnail_url": {},
                        }
                    ],
                    "poll": {
                        "duration_minutes": 0,
                        "options": ["string"],
                        "reply_settings": "following",
                    },
                    "quote_tweet_id": "quote_tweet_id",
                    "reply_settings": "following",
                },
                "youtube": {
                    "caption": {},
                    "made_for_kids": True,
                    "media": [
                        {
                            "url": "url",
                            "tags": [
                                {
                                    "id": "id",
                                    "platform": "facebook",
                                    "type": "user",
                                    "x": 0,
                                    "y": 0,
                                }
                            ],
                            "thumbnail_timestamp_ms": {},
                            "thumbnail_url": {},
                        }
                    ],
                    "privacy_status": "public",
                    "title": "title",
                },
            },
            scheduled_at=parse_datetime("2019-12-27T18:11:19.117Z"),
        )
        assert_matches_type(SocialPost, social_post, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_create(self, async_client: AsyncPostForMe) -> None:
        response = await async_client.social_posts.with_raw_response.create(
            caption="caption",
            social_accounts=["string"],
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        social_post = await response.parse()
        assert_matches_type(SocialPost, social_post, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_create(self, async_client: AsyncPostForMe) -> None:
        async with async_client.social_posts.with_streaming_response.create(
            caption="caption",
            social_accounts=["string"],
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            social_post = await response.parse()
            assert_matches_type(SocialPost, social_post, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_retrieve(self, async_client: AsyncPostForMe) -> None:
        social_post = await async_client.social_posts.retrieve(
            "id",
        )
        assert_matches_type(SocialPost, social_post, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_retrieve(self, async_client: AsyncPostForMe) -> None:
        response = await async_client.social_posts.with_raw_response.retrieve(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        social_post = await response.parse()
        assert_matches_type(SocialPost, social_post, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_retrieve(self, async_client: AsyncPostForMe) -> None:
        async with async_client.social_posts.with_streaming_response.retrieve(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            social_post = await response.parse()
            assert_matches_type(SocialPost, social_post, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_retrieve(self, async_client: AsyncPostForMe) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.social_posts.with_raw_response.retrieve(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_update(self, async_client: AsyncPostForMe) -> None:
        social_post = await async_client.social_posts.update(
            id="id",
            caption="caption",
            social_accounts=["string"],
        )
        assert_matches_type(SocialPost, social_post, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_update_with_all_params(self, async_client: AsyncPostForMe) -> None:
        social_post = await async_client.social_posts.update(
            id="id",
            caption="caption",
            social_accounts=["string"],
            account_configurations=[
                {
                    "configuration": {
                        "allow_comment": True,
                        "allow_duet": True,
                        "allow_stitch": True,
                        "auto_add_music": True,
                        "board_ids": ["string"],
                        "caption": {},
                        "collaborators": [[{}]],
                        "community_id": "community_id",
                        "disclose_branded_content": True,
                        "disclose_your_brand": True,
                        "is_ai_generated": True,
                        "is_draft": True,
                        "link": "link",
                        "location": "location",
                        "made_for_kids": True,
                        "media": [
                            {
                                "url": "url",
                                "tags": [
                                    {
                                        "id": "id",
                                        "platform": "facebook",
                                        "type": "user",
                                        "x": 0,
                                        "y": 0,
                                    }
                                ],
                                "thumbnail_timestamp_ms": {},
                                "thumbnail_url": {},
                            }
                        ],
                        "placement": "reels",
                        "poll": {
                            "duration_minutes": 0,
                            "options": ["string"],
                            "reply_settings": "following",
                        },
                        "privacy_status": "public",
                        "quote_tweet_id": "quote_tweet_id",
                        "reply_settings": "following",
                        "share_to_feed": True,
                        "title": "title",
                        "trial_reel_type": "manual",
                    },
                    "social_account_id": "social_account_id",
                }
            ],
            external_id="external_id",
            is_draft=True,
            media=[
                {
                    "url": "url",
                    "tags": [
                        {
                            "id": "id",
                            "platform": "facebook",
                            "type": "user",
                            "x": 0,
                            "y": 0,
                        }
                    ],
                    "thumbnail_timestamp_ms": {},
                    "thumbnail_url": {},
                }
            ],
            platform_configurations={
                "bluesky": {
                    "caption": {},
                    "media": [
                        {
                            "url": "url",
                            "tags": [
                                {
                                    "id": "id",
                                    "platform": "facebook",
                                    "type": "user",
                                    "x": 0,
                                    "y": 0,
                                }
                            ],
                            "thumbnail_timestamp_ms": {},
                            "thumbnail_url": {},
                        }
                    ],
                },
                "facebook": {
                    "caption": {},
                    "collaborators": [[{}]],
                    "location": "location",
                    "media": [
                        {
                            "url": "url",
                            "tags": [
                                {
                                    "id": "id",
                                    "platform": "facebook",
                                    "type": "user",
                                    "x": 0,
                                    "y": 0,
                                }
                            ],
                            "thumbnail_timestamp_ms": {},
                            "thumbnail_url": {},
                        }
                    ],
                    "placement": "reels",
                },
                "instagram": {
                    "caption": {},
                    "collaborators": ["string"],
                    "location": "location",
                    "media": [
                        {
                            "url": "url",
                            "tags": [
                                {
                                    "id": "id",
                                    "platform": "facebook",
                                    "type": "user",
                                    "x": 0,
                                    "y": 0,
                                }
                            ],
                            "thumbnail_timestamp_ms": {},
                            "thumbnail_url": {},
                        }
                    ],
                    "placement": "reels",
                    "share_to_feed": True,
                    "trial_reel_type": "manual",
                },
                "linkedin": {
                    "caption": {},
                    "media": [
                        {
                            "url": "url",
                            "tags": [
                                {
                                    "id": "id",
                                    "platform": "facebook",
                                    "type": "user",
                                    "x": 0,
                                    "y": 0,
                                }
                            ],
                            "thumbnail_timestamp_ms": {},
                            "thumbnail_url": {},
                        }
                    ],
                },
                "pinterest": {
                    "board_ids": ["string"],
                    "caption": {},
                    "link": "link",
                    "media": [
                        {
                            "url": "url",
                            "tags": [
                                {
                                    "id": "id",
                                    "platform": "facebook",
                                    "type": "user",
                                    "x": 0,
                                    "y": 0,
                                }
                            ],
                            "thumbnail_timestamp_ms": {},
                            "thumbnail_url": {},
                        }
                    ],
                },
                "threads": {
                    "caption": {},
                    "media": [
                        {
                            "url": "url",
                            "tags": [
                                {
                                    "id": "id",
                                    "platform": "facebook",
                                    "type": "user",
                                    "x": 0,
                                    "y": 0,
                                }
                            ],
                            "thumbnail_timestamp_ms": {},
                            "thumbnail_url": {},
                        }
                    ],
                    "placement": "reels",
                },
                "tiktok": {
                    "allow_comment": True,
                    "allow_duet": True,
                    "allow_stitch": True,
                    "auto_add_music": True,
                    "caption": {},
                    "disclose_branded_content": True,
                    "disclose_your_brand": True,
                    "is_ai_generated": True,
                    "is_draft": True,
                    "media": [
                        {
                            "url": "url",
                            "tags": [
                                {
                                    "id": "id",
                                    "platform": "facebook",
                                    "type": "user",
                                    "x": 0,
                                    "y": 0,
                                }
                            ],
                            "thumbnail_timestamp_ms": {},
                            "thumbnail_url": {},
                        }
                    ],
                    "privacy_status": "privacy_status",
                    "title": "title",
                },
                "tiktok_business": {
                    "allow_comment": True,
                    "allow_duet": True,
                    "allow_stitch": True,
                    "auto_add_music": True,
                    "caption": {},
                    "disclose_branded_content": True,
                    "disclose_your_brand": True,
                    "is_ai_generated": True,
                    "is_draft": True,
                    "media": [
                        {
                            "url": "url",
                            "tags": [
                                {
                                    "id": "id",
                                    "platform": "facebook",
                                    "type": "user",
                                    "x": 0,
                                    "y": 0,
                                }
                            ],
                            "thumbnail_timestamp_ms": {},
                            "thumbnail_url": {},
                        }
                    ],
                    "privacy_status": "privacy_status",
                    "title": "title",
                },
                "x": {
                    "caption": {},
                    "community_id": "community_id",
                    "media": [
                        {
                            "url": "url",
                            "tags": [
                                {
                                    "id": "id",
                                    "platform": "facebook",
                                    "type": "user",
                                    "x": 0,
                                    "y": 0,
                                }
                            ],
                            "thumbnail_timestamp_ms": {},
                            "thumbnail_url": {},
                        }
                    ],
                    "poll": {
                        "duration_minutes": 0,
                        "options": ["string"],
                        "reply_settings": "following",
                    },
                    "quote_tweet_id": "quote_tweet_id",
                    "reply_settings": "following",
                },
                "youtube": {
                    "caption": {},
                    "made_for_kids": True,
                    "media": [
                        {
                            "url": "url",
                            "tags": [
                                {
                                    "id": "id",
                                    "platform": "facebook",
                                    "type": "user",
                                    "x": 0,
                                    "y": 0,
                                }
                            ],
                            "thumbnail_timestamp_ms": {},
                            "thumbnail_url": {},
                        }
                    ],
                    "privacy_status": "public",
                    "title": "title",
                },
            },
            scheduled_at=parse_datetime("2019-12-27T18:11:19.117Z"),
        )
        assert_matches_type(SocialPost, social_post, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_update(self, async_client: AsyncPostForMe) -> None:
        response = await async_client.social_posts.with_raw_response.update(
            id="id",
            caption="caption",
            social_accounts=["string"],
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        social_post = await response.parse()
        assert_matches_type(SocialPost, social_post, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_update(self, async_client: AsyncPostForMe) -> None:
        async with async_client.social_posts.with_streaming_response.update(
            id="id",
            caption="caption",
            social_accounts=["string"],
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            social_post = await response.parse()
            assert_matches_type(SocialPost, social_post, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_update(self, async_client: AsyncPostForMe) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.social_posts.with_raw_response.update(
                id="",
                caption="caption",
                social_accounts=["string"],
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_list(self, async_client: AsyncPostForMe) -> None:
        social_post = await async_client.social_posts.list()
        assert_matches_type(SocialPostListResponse, social_post, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_list_with_all_params(self, async_client: AsyncPostForMe) -> None:
        social_post = await async_client.social_posts.list(
            external_id=["string"],
            limit=0,
            offset=0,
            platform=["bluesky"],
            social_account_id=["string"],
            status=["draft"],
        )
        assert_matches_type(SocialPostListResponse, social_post, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_list(self, async_client: AsyncPostForMe) -> None:
        response = await async_client.social_posts.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        social_post = await response.parse()
        assert_matches_type(SocialPostListResponse, social_post, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_list(self, async_client: AsyncPostForMe) -> None:
        async with async_client.social_posts.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            social_post = await response.parse()
            assert_matches_type(SocialPostListResponse, social_post, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_delete(self, async_client: AsyncPostForMe) -> None:
        social_post = await async_client.social_posts.delete(
            "id",
        )
        assert_matches_type(SocialPostDeleteResponse, social_post, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_delete(self, async_client: AsyncPostForMe) -> None:
        response = await async_client.social_posts.with_raw_response.delete(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        social_post = await response.parse()
        assert_matches_type(SocialPostDeleteResponse, social_post, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_delete(self, async_client: AsyncPostForMe) -> None:
        async with async_client.social_posts.with_streaming_response.delete(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            social_post = await response.parse()
            assert_matches_type(SocialPostDeleteResponse, social_post, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_delete(self, async_client: AsyncPostForMe) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.social_posts.with_raw_response.delete(
                "",
            )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from .._models import BaseModel
from .social_post import SocialPost

__all__ = ["SocialPostListResponse", "Meta"]


class Meta(BaseModel):
    limit: float
    """Maximum number of items returned."""

    next: Optional[str] = None
    """URL to the next page of results, or null if none."""

    offset: float
    """Number of items skipped."""

    total: float
    """Total number of items available."""


class SocialPostListResponse(BaseModel):
    data: List[SocialPost]

    meta: Meta



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from typing_extensions import Literal

from .._models import BaseModel

__all__ = ["FacebookConfigurationDto", "Media", "MediaTag"]


class MediaTag(BaseModel):
    id: str
    """Facebook User ID, Instagram Username or Instagram product id to tag"""

    platform: Literal["facebook", "instagram"]
    """The platform for the tags"""

    type: Literal["user", "product"]
    """
    The type of tag, user to tag accounts, product to tag products (only supported
    for instagram)
    """

    x: Optional[float] = None
    """
    Percentage distance from left edge of the image, Not required for videos or
    stories
    """

    y: Optional[float] = None
    """
    Percentage distance from top edge of the image, Not required for videos or
    stories
    """


class Media(BaseModel):
    url: str
    """Public URL of the media"""

    tags: Optional[List[MediaTag]] = None
    """List of tags to attach to the media"""

    thumbnail_timestamp_ms: Optional[object] = None
    """Timestamp in milliseconds of frame to use as thumbnail for the media"""

    thumbnail_url: Optional[object] = None
    """Public URL of the thumbnail for the media"""


class FacebookConfigurationDto(BaseModel):
    caption: Optional[object] = None
    """Overrides the `caption` from the post"""

    collaborators: Optional[List[List[object]]] = None
    """List of page ids to invite as collaborators for a Video Reel"""

    location: Optional[str] = None
    """Page id with a location that you want to tag the image or video with"""

    media: Optional[List[Media]] = None
    """Overrides the `media` from the post"""

    placement: Optional[Literal["reels", "stories", "timeline"]] = None
    """Facebook post placement"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from .._models import BaseModel

__all__ = ["SocialPostResult", "PlatformData"]


class PlatformData(BaseModel):
    """Platform-specific data"""

    id: Optional[str] = None
    """Platform-specific ID"""

    url: Optional[str] = None
    """URL of the posted content"""


class SocialPostResult(BaseModel):
    id: str
    """The unique identifier of the post result"""

    details: object
    """Detailed logs from the post"""

    error: object
    """Error message if the post failed"""

    platform_data: PlatformData
    """Platform-specific data"""

    post_id: str
    """The ID of the associated post"""

    social_account_id: str
    """The ID of the associated social account"""

    success: bool
    """Indicates if the post was successful"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Union, Optional
from datetime import datetime
from typing_extensions import Literal, Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["SocialAccountCreateParams"]


class SocialAccountCreateParams(TypedDict, total=False):
    access_token: Required[str]
    """The access token of the social account"""

    access_token_expires_at: Required[Annotated[Union[str, datetime], PropertyInfo(format="iso8601")]]
    """The access token expiration date of the social account"""

    platform: Required[
        Literal[
            "facebook",
            "instagram",
            "x",
            "tiktok",
            "youtube",
            "pinterest",
            "linkedin",
            "bluesky",
            "threads",
            "tiktok_business",
        ]
    ]
    """The platform of the social account"""

    user_id: Required[str]
    """The user id of the social account"""

    external_id: Optional[str]
    """The external id of the social account"""

    metadata: object
    """The metadata of the social account"""

    refresh_token: Optional[str]
    """The refresh token of the social account"""

    refresh_token_expires_at: Annotated[Union[str, datetime, None], PropertyInfo(format="iso8601")]
    """The refresh token expiration date of the social account"""

    username: Optional[str]
    """The platform's username of the social account"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List, Iterable
from typing_extensions import Literal, Required, TypedDict

__all__ = [
    "SocialAccountCreateAuthURLParams",
    "PlatformData",
    "PlatformDataBluesky",
    "PlatformDataFacebook",
    "PlatformDataInstagram",
    "PlatformDataLinkedin",
    "PlatformDataPinterest",
    "PlatformDataThreads",
    "PlatformDataTiktok",
    "PlatformDataTiktokBusiness",
    "PlatformDataYoutube",
]


class SocialAccountCreateAuthURLParams(TypedDict, total=False):
    platform: Required[str]
    """The social account provider"""

    external_id: str
    """Your unique identifier for the social account"""

    permissions: List[Literal["posts", "feeds"]]
    """List of permissions you want to allow.

    Will default to only post permissions. You must include the "feeds" permission
    to request an account feed and metrics
    """

    platform_data: PlatformData
    """Additional data needed for the provider"""

    redirect_url_override: str
    """Override the default redirect URL for the OAuth flow.

    If provided, this URL will be used instead of our redirect URL. Make sure this
    URL is included in your app's authorized redirect urls. This override will not
    work when using our system credientals.
    """


class PlatformDataBluesky(TypedDict, total=False):
    """Additional data needed for connecting bluesky accounts"""

    app_password: Required[str]
    """The app password of the account"""

    handle: Required[str]
    """The handle of the account"""


class PlatformDataFacebook(TypedDict, total=False):
    """Additional data for connecting facebook accounts"""

    permission_overrides: Iterable[Iterable[object]]
    """Override the default permissions/scopes requested during OAuth.

    Default scopes: public_profile, pages_show_list, pages_read_engagement,
    pages_manage_posts, business_management
    """


class PlatformDataInstagram(TypedDict, total=False):
    """Additional data for connecting instagram accounts"""

    connection_type: Required[Literal["instagram", "facebook"]]
    """
    The type of connection; instagram for using login with instagram, facebook for
    using login with facebook.
    """

    permission_overrides: Iterable[Iterable[object]]
    """Override the default permissions/scopes requested during OAuth.

    Default instagram scopes: instagram_business_basic,
    instagram_business_content_publish. Default facebook scopes: instagram_basic,
    instagram_content_publish, pages_show_list, public_profile, business_management
    """


class PlatformDataLinkedin(TypedDict, total=False):
    """Additional data for connecting linkedin accounts"""

    connection_type: Required[Literal["personal", "organization"]]
    """
    The type of connection; If using our provided credentials always use
    "organization". If using your own crednetials then only use "organization" if
    you are using the Community API
    """

    permission_overrides: Iterable[Iterable[object]]
    """Override the default permissions/scopes requested during OAuth.

    Default personal scopes: openid, w_member_social, profile, email. Default
    organization scopes: r_basicprofile, w_member_social, r_organization_social,
    w_organization_social, rw_organization_admin
    """


class PlatformDataPinterest(TypedDict, total=False):
    """Additional data for connecting Pinterest accounts"""

    permission_overrides: Iterable[Iterable[object]]
    """Override the default permissions/scopes requested during OAuth.

    Default scopes: boards:read, boards:write, pins:read, pins:write,
    user_accounts:read
    """


class PlatformDataThreads(TypedDict, total=False):
    """Additional data for connecting Threads accounts"""

    permission_overrides: Iterable[Iterable[object]]
    """Override the default permissions/scopes requested during OAuth.

    Default scopes: threads_basic, threads_content_publish
    """


class PlatformDataTiktok(TypedDict, total=False):
    """Additional data for connecting TikTok accounts"""

    permission_overrides: Iterable[Iterable[object]]
    """Override the default permissions/scopes requested during OAuth.

    Default scopes: user.info.basic, video.list, video.upload, video.publish
    """


class PlatformDataTiktokBusiness(TypedDict, total=False):
    """Additional data for connecting TikTok Business accounts"""

    permission_overrides: Iterable[Iterable[object]]
    """Override the default permissions/scopes requested during OAuth.

    Default scopes: user.info.basic, user.info.username, user.info.stats,
    user.info.profile, user.account.type, user.insights, video.list, video.insights,
    comment.list, comment.list.manage, video.publish, video.upload, biz.spark.auth,
    discovery.search.words
    """


class PlatformDataYoutube(TypedDict, total=False):
    """Additional data for connecting YouTube accounts"""

    permission_overrides: Iterable[Iterable[object]]
    """Override the default permissions/scopes requested during OAuth.

    Default scopes: https://www.googleapis.com/auth/youtube.force-ssl,
    https://www.googleapis.com/auth/youtube.upload,
    https://www.googleapis.com/auth/youtube.readonly,
    https://www.googleapis.com/auth/userinfo.profile
    """


class PlatformData(TypedDict, total=False):
    """Additional data needed for the provider"""

    bluesky: PlatformDataBluesky
    """Additional data needed for connecting bluesky accounts"""

    facebook: PlatformDataFacebook
    """Additional data for connecting facebook accounts"""

    instagram: PlatformDataInstagram
    """Additional data for connecting instagram accounts"""

    linkedin: PlatformDataLinkedin
    """Additional data for connecting linkedin accounts"""

    pinterest: PlatformDataPinterest
    """Additional data for connecting Pinterest accounts"""

    threads: PlatformDataThreads
    """Additional data for connecting Threads accounts"""

    tiktok: PlatformDataTiktok
    """Additional data for connecting TikTok accounts"""

    tiktok_business: PlatformDataTiktokBusiness
    """Additional data for connecting TikTok Business accounts"""

    youtube: PlatformDataYoutube
    """Additional data for connecting YouTube accounts"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Iterable, Optional
from typing_extensions import Literal, Required, TypedDict

__all__ = ["LinkedinConfigurationDtoParam", "Media", "MediaTag"]


class MediaTag(TypedDict, total=False):
    id: Required[str]
    """Facebook User ID, Instagram Username or Instagram product id to tag"""

    platform: Required[Literal["facebook", "instagram"]]
    """The platform for the tags"""

    type: Required[Literal["user", "product"]]
    """
    The type of tag, user to tag accounts, product to tag products (only supported
    for instagram)
    """

    x: float
    """
    Percentage distance from left edge of the image, Not required for videos or
    stories
    """

    y: float
    """
    Percentage distance from top edge of the image, Not required for videos or
    stories
    """


class Media(TypedDict, total=False):
    url: Required[str]
    """Public URL of the media"""

    tags: Optional[Iterable[MediaTag]]
    """List of tags to attach to the media"""

    thumbnail_timestamp_ms: Optional[object]
    """Timestamp in milliseconds of frame to use as thumbnail for the media"""

    thumbnail_url: Optional[object]
    """Public URL of the thumbnail for the media"""


class LinkedinConfigurationDtoParam(TypedDict, total=False):
    caption: Optional[object]
    """Overrides the `caption` from the post"""

    media: Optional[Iterable[Media]]
    """Overrides the `media` from the post"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List
from typing_extensions import Literal

import httpx

from ..types import social_account_feed_list_params
from .._types import Body, Omit, Query, Headers, NotGiven, SequenceNotStr, omit, not_given
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.social_account_feed_list_response import SocialAccountFeedListResponse

__all__ = ["SocialAccountFeedsResource", "AsyncSocialAccountFeedsResource"]


class SocialAccountFeedsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> SocialAccountFeedsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/DayMoonDevelopment/post-for-me-python#accessing-raw-response-data-eg-headers
        """
        return SocialAccountFeedsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> SocialAccountFeedsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/DayMoonDevelopment/post-for-me-python#with_streaming_response
        """
        return SocialAccountFeedsResourceWithStreamingResponse(self)

    def list(
        self,
        social_account_id: str,
        *,
        cursor: str | Omit = omit,
        expand: List[Literal["metrics"]] | Omit = omit,
        external_post_id: SequenceNotStr[str] | Omit = omit,
        limit: float | Omit = omit,
        platform_post_id: SequenceNotStr[str] | Omit = omit,
        social_post_id: SequenceNotStr[str] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SocialAccountFeedListResponse:
        """
        Get a paginated result for the social account based on the applied filters

        Args:
          cursor: Cursor identifying next page of results

          expand: Expand additional data in the response. Currently supports: "metrics" to include
              post analytics data.

          external_post_id: Filter by Post for Me Social Postexternal ID. Multiple values imply OR logic
              (e.g., ?external_post_id=xxxxxx&external_post_id=yyyyyy).

          limit: Number of items to return; Note: some platforms will have different max limits,
              in the case the provided limit is over the platform's limit we will return the
              max allowed by the platform.

          platform_post_id: Filter by the platform's id(s). Multiple values imply OR logic (e.g.,
              ?social_post_id=spr_xxxxxx&social_post_id=spr_yyyyyy).

          social_post_id: Filter by Post for Me Social Post id(s). Multiple values imply OR logic (e.g.,
              ?social_post_id=sp_xxxxxx&social_post_id=sp_yyyyyy).

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not social_account_id:
            raise ValueError(f"Expected a non-empty value for `social_account_id` but received {social_account_id!r}")
        return self._get(
            f"/v1/social-account-feeds/{social_account_id}",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "cursor": cursor,
                        "expand": expand,
                        "external_post_id": external_post_id,
                        "limit": limit,
                        "platform_post_id": platform_post_id,
                        "social_post_id": social_post_id,
                    },
                    social_account_feed_list_params.SocialAccountFeedListParams,
                ),
            ),
            cast_to=SocialAccountFeedListResponse,
        )


class AsyncSocialAccountFeedsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncSocialAccountFeedsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/DayMoonDevelopment/post-for-me-python#accessing-raw-response-data-eg-headers
        """
        return AsyncSocialAccountFeedsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncSocialAccountFeedsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/DayMoonDevelopment/post-for-me-python#with_streaming_response
        """
        return AsyncSocialAccountFeedsResourceWithStreamingResponse(self)

    async def list(
        self,
        social_account_id: str,
        *,
        cursor: str | Omit = omit,
        expand: List[Literal["metrics"]] | Omit = omit,
        external_post_id: SequenceNotStr[str] | Omit = omit,
        limit: float | Omit = omit,
        platform_post_id: SequenceNotStr[str] | Omit = omit,
        social_post_id: SequenceNotStr[str] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SocialAccountFeedListResponse:
        """
        Get a paginated result for the social account based on the applied filters

        Args:
          cursor: Cursor identifying next page of results

          expand: Expand additional data in the response. Currently supports: "metrics" to include
              post analytics data.

          external_post_id: Filter by Post for Me Social Postexternal ID. Multiple values imply OR logic
              (e.g., ?external_post_id=xxxxxx&external_post_id=yyyyyy).

          limit: Number of items to return; Note: some platforms will have different max limits,
              in the case the provided limit is over the platform's limit we will return the
              max allowed by the platform.

          platform_post_id: Filter by the platform's id(s). Multiple values imply OR logic (e.g.,
              ?social_post_id=spr_xxxxxx&social_post_id=spr_yyyyyy).

          social_post_id: Filter by Post for Me Social Post id(s). Multiple values imply OR logic (e.g.,
              ?social_post_id=sp_xxxxxx&social_post_id=sp_yyyyyy).

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not social_account_id:
            raise ValueError(f"Expected a non-empty value for `social_account_id` but received {social_account_id!r}")
        return await self._get(
            f"/v1/social-account-feeds/{social_account_id}",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "cursor": cursor,
                        "expand": expand,
                        "external_post_id": external_post_id,
                        "limit": limit,
                        "platform_post_id": platform_post_id,
                        "social_post_id": social_post_id,
                    },
                    social_account_feed_list_params.SocialAccountFeedListParams,
                ),
            ),
            cast_to=SocialAccountFeedListResponse,
        )


class SocialAccountFeedsResourceWithRawResponse:
    def __init__(self, social_account_feeds: SocialAccountFeedsResource) -> None:
        self._social_account_feeds = social_account_feeds

        self.list = to_raw_response_wrapper(
            social_account_feeds.list,
        )


class AsyncSocialAccountFeedsResourceWithRawResponse:
    def __init__(self, social_account_feeds: AsyncSocialAccountFeedsResource) -> None:
        self._social_account_feeds = social_account_feeds

        self.list = async_to_raw_response_wrapper(
            social_account_feeds.list,
        )


class SocialAccountFeedsResourceWithStreamingResponse:
    def __init__(self, social_account_feeds: SocialAccountFeedsResource) -> None:
        self._social_account_feeds = social_account_feeds

        self.list = to_streamed_response_wrapper(
            social_account_feeds.list,
        )


class AsyncSocialAccountFeedsResourceWithStreamingResponse:
    def __init__(self, social_account_feeds: AsyncSocialAccountFeedsResource) -> None:
        self._social_account_feeds = social_account_feeds

        self.list = async_to_streamed_response_wrapper(
            social_account_feeds.list,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Union, Optional
from datetime import datetime
from typing_extensions import TypeAlias

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = [
    "PlatformPost",
    "Metrics",
    "MetricsTikTokBusinessMetricsDto",
    "MetricsTikTokBusinessMetricsDtoAudienceCity",
    "MetricsTikTokBusinessMetricsDtoAudienceCountry",
    "MetricsTikTokBusinessMetricsDtoAudienceGender",
    "MetricsTikTokBusinessMetricsDtoAudienceType",
    "MetricsTikTokBusinessMetricsDtoEngagementLike",
    "MetricsTikTokBusinessMetricsDtoImpressionSource",
    "MetricsTikTokBusinessMetricsDtoVideoViewRetention",
    "MetricsTikTokPostMetricsDto",
    "MetricsInstagramPostMetricsDto",
    "MetricsYouTubePostMetricsDto",
    "MetricsFacebookPostMetricsDto",
    "MetricsFacebookPostMetricsDtoActivityByActionType",
    "MetricsFacebookPostMetricsDtoActivityByActionTypeUnique",
    "MetricsFacebookPostMetricsDtoVideoRetentionGraphAutoplayed",
    "MetricsFacebookPostMetricsDtoVideoRetentionGraphClickedToPlay",
    "MetricsFacebookPostMetricsDtoVideoViewTimeByAgeGender",
    "MetricsFacebookPostMetricsDtoVideoViewTimeByCountry",
    "MetricsFacebookPostMetricsDtoVideoViewTimeByRegion",
    "MetricsTwitterPostMetricsDto",
    "MetricsTwitterPostMetricsDtoNonPublicMetrics",
    "MetricsTwitterPostMetricsDtoOrganicMetrics",
    "MetricsTwitterPostMetricsDtoPublicMetrics",
    "MetricsThreadsPostMetricsDto",
    "MetricsLinkedInPostMetricsDto",
    "MetricsBlueskyPostMetricsDto",
    "MetricsPinterestPostMetricsDto",
    "MetricsPinterestPostMetricsDto_90d",
    "MetricsPinterestPostMetricsDtoLifetimeMetrics",
]


class MetricsTikTokBusinessMetricsDtoAudienceCity(BaseModel):
    city_name: str
    """City name"""

    percentage: float
    """Percentage of audience from this city"""


class MetricsTikTokBusinessMetricsDtoAudienceCountry(BaseModel):
    country: str
    """Country name"""

    percentage: float
    """Percentage of audience from this country"""


class MetricsTikTokBusinessMetricsDtoAudienceGender(BaseModel):
    gender: str
    """Gender category"""

    percentage: float
    """Percentage of audience of this gender"""


class MetricsTikTokBusinessMetricsDtoAudienceType(BaseModel):
    percentage: float
    """Percentage of audience of this type"""

    type: str
    """Type of audience"""


class MetricsTikTokBusinessMetricsDtoEngagementLike(BaseModel):
    percentage: float
    """Percentage value for the metric"""

    second: str
    """Time in seconds for the metric"""


class MetricsTikTokBusinessMetricsDtoImpressionSource(BaseModel):
    impression_source: str
    """Name of the impression source"""

    percentage: float
    """Percentage of impressions from this source"""


class MetricsTikTokBusinessMetricsDtoVideoViewRetention(BaseModel):
    percentage: float
    """Percentage value for the metric"""

    second: str
    """Time in seconds for the metric"""


class MetricsTikTokBusinessMetricsDto(BaseModel):
    address_clicks: float
    """Number of address clicks"""

    app_download_clicks: float
    """Number of app download clicks"""

    audience_cities: List[MetricsTikTokBusinessMetricsDtoAudienceCity]
    """Audience cities breakdown"""

    audience_countries: List[MetricsTikTokBusinessMetricsDtoAudienceCountry]
    """Audience countries breakdown"""

    audience_genders: List[MetricsTikTokBusinessMetricsDtoAudienceGender]
    """Audience genders breakdown"""

    audience_types: List[MetricsTikTokBusinessMetricsDtoAudienceType]
    """Audience types breakdown"""

    average_time_watched: float
    """Average time watched in seconds"""

    comments: float
    """Number of comments on the post"""

    email_clicks: float
    """Number of email clicks"""

    engagement_likes: List[MetricsTikTokBusinessMetricsDtoEngagementLike]
    """Engagement likes data by percentage and time"""

    favorites: float
    """Number of favorites on the post"""

    full_video_watched_rate: float
    """Rate of full video watches as a percentage"""

    impression_sources: List[MetricsTikTokBusinessMetricsDtoImpressionSource]
    """Impression sources breakdown"""

    lead_submissions: float
    """Number of lead submissions"""

    likes: float
    """Number of likes on the post"""

    new_followers: float
    """Number of new followers gained from the post"""

    phone_number_clicks: float
    """Number of phone number clicks"""

    profile_views: float
    """Number of profile views generated"""

    reach: float
    """Total reach of the post"""

    shares: float
    """Number of shares on the post"""

    total_time_watched: float
    """Total time watched in seconds"""

    video_view_retention: List[MetricsTikTokBusinessMetricsDtoVideoViewRetention]
    """Video view retention data by percentage and time"""

    video_views: float
    """Total number of video views"""

    website_clicks: float
    """Number of website clicks"""


class MetricsTikTokPostMetricsDto(BaseModel):
    comment_count: float
    """Number of comments on the video"""

    like_count: float
    """Number of likes on the video"""

    share_count: float
    """Number of shares of the video"""

    view_count: float
    """Number of views on the video"""


class MetricsInstagramPostMetricsDto(BaseModel):
    comments: Optional[float] = None
    """Number of comments on the post"""

    follows: Optional[float] = None
    """Number of new follows from this post"""

    ig_reels_avg_watch_time: Optional[float] = None
    """Average watch time for Reels (in milliseconds)"""

    ig_reels_video_view_total_time: Optional[float] = None
    """Total watch time for Reels (in milliseconds)"""

    likes: Optional[float] = None
    """Number of likes on the post"""

    navigation: Optional[float] = None
    """Navigation actions taken on the media"""

    profile_activity: Optional[float] = None
    """Profile activity generated from this post"""

    profile_visits: Optional[float] = None
    """Number of profile visits from this post"""

    reach: Optional[float] = None
    """Total number of unique accounts that have seen the media"""

    replies: Optional[float] = None
    """Number of replies to the story (story media only)"""

    saved: Optional[float] = None
    """Total number of unique accounts that have saved the media"""

    shares: Optional[float] = None
    """Total number of shares of the media"""

    total_interactions: Optional[float] = None
    """Total interactions on the post"""

    views: Optional[float] = None
    """Number of views on the post"""


class MetricsYouTubePostMetricsDto(BaseModel):
    comments: float
    """Number of comments on the video"""

    dislikes: float
    """Number of dislikes on the video"""

    likes: float
    """Number of likes on the video"""

    views: float
    """Number of views on the video"""

    annotation_clickable_impressions: Optional[float] = FieldInfo(alias="annotationClickableImpressions", default=None)
    """Number of clickable annotation impressions"""

    annotation_clicks: Optional[float] = FieldInfo(alias="annotationClicks", default=None)
    """Number of annotation clicks"""

    annotation_click_through_rate: Optional[float] = FieldInfo(alias="annotationClickThroughRate", default=None)
    """Annotation click-through rate"""

    annotation_closable_impressions: Optional[float] = FieldInfo(alias="annotationClosableImpressions", default=None)
    """Number of closable annotation impressions"""

    annotation_close_rate: Optional[float] = FieldInfo(alias="annotationCloseRate", default=None)
    """Annotation close rate"""

    annotation_closes: Optional[float] = FieldInfo(alias="annotationCloses", default=None)
    """Number of annotation closes"""

    annotation_impressions: Optional[float] = FieldInfo(alias="annotationImpressions", default=None)
    """Number of annotation impressions"""

    average_view_duration: Optional[float] = FieldInfo(alias="averageViewDuration", default=None)
    """Average view duration in seconds"""

    average_view_percentage: Optional[float] = FieldInfo(alias="averageViewPercentage", default=None)
    """Average percentage of the video watched"""

    card_click_rate: Optional[float] = FieldInfo(alias="cardClickRate", default=None)
    """Card click-through rate"""

    card_clicks: Optional[float] = FieldInfo(alias="cardClicks", default=None)
    """Number of card clicks"""

    card_impressions: Optional[float] = FieldInfo(alias="cardImpressions", default=None)
    """Number of card impressions"""

    card_teaser_click_rate: Optional[float] = FieldInfo(alias="cardTeaserClickRate", default=None)
    """Card teaser click-through rate"""

    card_teaser_clicks: Optional[float] = FieldInfo(alias="cardTeaserClicks", default=None)
    """Number of card teaser clicks"""

    card_teaser_impressions: Optional[float] = FieldInfo(alias="cardTeaserImpressions", default=None)
    """Number of card teaser impressions"""

    engaged_views: Optional[float] = FieldInfo(alias="engagedViews", default=None)
    """Number of engaged views"""

    estimated_minutes_watched: Optional[float] = FieldInfo(alias="estimatedMinutesWatched", default=None)
    """Estimated minutes watched"""

    estimated_red_minutes_watched: Optional[float] = FieldInfo(alias="estimatedRedMinutesWatched", default=None)
    """Estimated minutes watched by YouTube Premium (Red) members"""

    red_views: Optional[float] = FieldInfo(alias="redViews", default=None)
    """Number of views from YouTube Premium (Red) members"""

    shares: Optional[float] = None
    """Number of shares"""

    subscribers_gained: Optional[float] = FieldInfo(alias="subscribersGained", default=None)
    """Subscribers gained"""

    subscribers_lost: Optional[float] = FieldInfo(alias="subscribersLost", default=None)
    """Subscribers lost"""

    videos_added_to_playlists: Optional[float] = FieldInfo(alias="videosAddedToPlaylists", default=None)
    """Number of times the video was added to playlists"""

    videos_removed_from_playlists: Optional[float] = FieldInfo(alias="videosRemovedFromPlaylists", default=None)
    """Number of times the video was removed from playlists"""


class MetricsFacebookPostMetricsDtoActivityByActionType(BaseModel):
    action_type: str
    """Action type (e.g., like, comment, share)"""

    value: float
    """Number of actions"""


class MetricsFacebookPostMetricsDtoActivityByActionTypeUnique(BaseModel):
    action_type: str
    """Action type (e.g., like, comment, share)"""

    value: float
    """Number of actions"""


class MetricsFacebookPostMetricsDtoVideoRetentionGraphAutoplayed(BaseModel):
    rate: float
    """Percentage of viewers at this time"""

    time: float
    """Time in seconds"""


class MetricsFacebookPostMetricsDtoVideoRetentionGraphClickedToPlay(BaseModel):
    rate: float
    """Percentage of viewers at this time"""

    time: float
    """Time in seconds"""


class MetricsFacebookPostMetricsDtoVideoViewTimeByAgeGender(BaseModel):
    key: str
    """Demographic key (e.g., age_gender, region, country)"""

    value: float
    """Total view time in milliseconds"""


class MetricsFacebookPostMetricsDtoVideoViewTimeByCountry(BaseModel):
    key: str
    """Demographic key (e.g., age_gender, region, country)"""

    value: float
    """Total view time in milliseconds"""


class MetricsFacebookPostMetricsDtoVideoViewTimeByRegion(BaseModel):
    key: str
    """Demographic key (e.g., age_gender, region, country)"""

    value: float
    """Total view time in milliseconds"""


class MetricsFacebookPostMetricsDto(BaseModel):
    activity_by_action_type: Optional[List[MetricsFacebookPostMetricsDtoActivityByActionType]] = None
    """Total activity breakdown by action type"""

    activity_by_action_type_unique: Optional[List[MetricsFacebookPostMetricsDtoActivityByActionTypeUnique]] = None
    """Unique users activity breakdown by action type"""

    comments: Optional[float] = None
    """Number of comments (from post object)"""

    fan_reach: Optional[float] = None
    """Number of fans who saw the post"""

    media_views: Optional[float] = None
    """Number of times the photo or video was viewed"""

    nonviral_reach: Optional[float] = None
    """Number of people who saw the post via non-viral distribution"""

    organic_reach: Optional[float] = None
    """Number of people who saw the post via organic distribution"""

    paid_reach: Optional[float] = None
    """Number of people who saw the post via paid distribution"""

    reach: Optional[float] = None
    """Total number of unique people who saw the post"""

    reactions_anger: Optional[float] = None
    """Number of anger reactions"""

    reactions_by_type: Optional[object] = None
    """Breakdown of all reaction types"""

    reactions_haha: Optional[float] = None
    """Number of haha reactions"""

    reactions_like: Optional[float] = None
    """Number of like reactions"""

    reactions_love: Optional[float] = None
    """Number of love reactions"""

    reactions_sorry: Optional[float] = None
    """Number of sad reactions"""

    reactions_total: Optional[float] = None
    """Total number of reactions (all types)"""

    reactions_wow: Optional[float] = None
    """Number of wow reactions"""

    shares: Optional[float] = None
    """Number of shares (from post object)"""

    video_avg_time_watched: Optional[float] = None
    """Average time video was viewed in milliseconds"""

    video_complete_views_organic: Optional[float] = None
    """Number of times video was viewed to 95% organically"""

    video_complete_views_organic_unique: Optional[float] = None
    """Number of unique people who viewed video to 95% organically"""

    video_complete_views_paid: Optional[float] = None
    """Number of times video was viewed to 95% via paid distribution"""

    video_complete_views_paid_unique: Optional[float] = None
    """Number of unique people who viewed video to 95% via paid distribution"""

    video_length: Optional[float] = None
    """Length of the video in milliseconds"""

    video_retention_graph_autoplayed: Optional[List[MetricsFacebookPostMetricsDtoVideoRetentionGraphAutoplayed]] = None
    """Video retention graph for autoplayed views"""

    video_retention_graph_clicked_to_play: Optional[
        List[MetricsFacebookPostMetricsDtoVideoRetentionGraphClickedToPlay]
    ] = None
    """Video retention graph for clicked-to-play views"""

    video_social_actions_unique: Optional[float] = None
    """Number of unique people who performed social actions on the video"""

    video_view_time: Optional[float] = None
    """Total time video was viewed in milliseconds"""

    video_view_time_by_age_gender: Optional[List[MetricsFacebookPostMetricsDtoVideoViewTimeByAgeGender]] = None
    """Video view time breakdown by age and gender"""

    video_view_time_by_country: Optional[List[MetricsFacebookPostMetricsDtoVideoViewTimeByCountry]] = None
    """Video view time breakdown by country"""

    video_view_time_by_distribution_type: Optional[object] = None
    """Video view time breakdown by distribution type"""

    video_view_time_by_region: Optional[List[MetricsFacebookPostMetricsDtoVideoViewTimeByRegion]] = None
    """Video view time breakdown by region"""

    video_view_time_organic: Optional[float] = None
    """Total time video was viewed in milliseconds via organic distribution"""

    video_views: Optional[float] = None
    """Number of times video was viewed for 3+ seconds"""

    video_views_15s: Optional[float] = None
    """Number of times video was viewed for 15+ seconds"""

    video_views_60s: Optional[float] = None
    """
    Number of times video was viewed for 60+ seconds (excludes videos shorter than
    60s)
    """

    video_views_autoplayed: Optional[float] = None
    """Number of times video was autoplayed for 3+ seconds"""

    video_views_by_distribution_type: Optional[object] = None
    """Video views breakdown by distribution type"""

    video_views_clicked_to_play: Optional[float] = None
    """Number of times video was clicked to play for 3+ seconds"""

    video_views_organic: Optional[float] = None
    """Number of times video was viewed for 3+ seconds organically"""

    video_views_organic_unique: Optional[float] = None
    """Number of unique people who viewed the video for 3+ seconds organically"""

    video_views_paid: Optional[float] = None
    """Number of times video was viewed for 3+ seconds via paid distribution"""

    video_views_paid_unique: Optional[float] = None
    """
    Number of unique people who viewed the video for 3+ seconds via paid
    distribution
    """

    video_views_sound_on: Optional[float] = None
    """Number of times video was viewed with sound on"""

    video_views_unique: Optional[float] = None
    """Number of unique people who viewed the video for 3+ seconds"""

    viral_reach: Optional[float] = None
    """Number of people who saw the post in News Feed via viral reach"""


class MetricsTwitterPostMetricsDtoNonPublicMetrics(BaseModel):
    """Non-public metrics for the Tweet (available to the Tweet owner or advertisers)"""

    impression_count: float
    """Number of times this Tweet has been viewed via promoted distribution"""

    url_link_clicks: float
    """Number of clicks on links in this Tweet via promoted distribution"""

    user_profile_clicks: float
    """Number of clicks on the author's profile via promoted distribution"""


class MetricsTwitterPostMetricsDtoOrganicMetrics(BaseModel):
    """Organic metrics for the Tweet (available to the Tweet owner)"""

    impression_count: float
    """Number of times this Tweet has been viewed organically"""

    like_count: float
    """Number of Likes of this Tweet from organic distribution"""

    reply_count: float
    """Number of Replies of this Tweet from organic distribution"""

    retweet_count: float
    """Number of Retweets of this Tweet from organic distribution"""

    url_link_clicks: float
    """Number of clicks on links in this Tweet from organic distribution"""

    user_profile_clicks: float
    """Number of clicks on the author's profile from organic distribution"""


class MetricsTwitterPostMetricsDtoPublicMetrics(BaseModel):
    """Publicly available metrics for the Tweet"""

    bookmark_count: float
    """Number of times this Tweet has been bookmarked"""

    impression_count: float
    """Number of times this Tweet has been viewed"""

    like_count: float
    """Number of Likes of this Tweet"""

    quote_count: float
    """Number of Quotes of this Tweet"""

    reply_count: float
    """Number of Replies of this Tweet"""

    retweet_count: float
    """Number of Retweets of this Tweet"""


class MetricsTwitterPostMetricsDto(BaseModel):
    non_public_metrics: Optional[MetricsTwitterPostMetricsDtoNonPublicMetrics] = None
    """Non-public metrics for the Tweet (available to the Tweet owner or advertisers)"""

    organic_metrics: Optional[MetricsTwitterPostMetricsDtoOrganicMetrics] = None
    """Organic metrics for the Tweet (available to the Tweet owner)"""

    public_metrics: Optional[MetricsTwitterPostMetricsDtoPublicMetrics] = None
    """Publicly available metrics for the Tweet"""


class MetricsThreadsPostMetricsDto(BaseModel):
    likes: float
    """Number of likes on the post"""

    quotes: float
    """Number of quotes of the post"""

    replies: float
    """Number of replies on the post"""

    reposts: float
    """Number of reposts of the post"""

    shares: float
    """Number of shares of the post"""

    views: float
    """Number of views on the post"""


class MetricsLinkedInPostMetricsDto(BaseModel):
    click_count: Optional[float] = FieldInfo(alias="clickCount", default=None)
    """Number of clicks"""

    comment_count: Optional[float] = FieldInfo(alias="commentCount", default=None)
    """Number of comments"""

    engagement: Optional[float] = None
    """Engagement rate"""

    impression_count: Optional[float] = FieldInfo(alias="impressionCount", default=None)
    """Number of impressions"""

    like_count: Optional[float] = FieldInfo(alias="likeCount", default=None)
    """Number of likes"""

    share_count: Optional[float] = FieldInfo(alias="shareCount", default=None)
    """Number of shares"""

    time_watched: Optional[float] = FieldInfo(alias="timeWatched", default=None)
    """TIME_WATCHED: The time the video was watched in milliseconds.

    Video auto-looping will continue to increase this metric for each subsequent
    play
    """

    time_watched_for_video_views: Optional[float] = FieldInfo(alias="timeWatchedForVideoViews", default=None)
    """
    TIME_WATCHED_FOR_VIDEO_VIEWS: The time watched in milliseconds for video
    play-pause cycles that are at least 3 seconds. Video auto-looping will continue
    to increase this metric for each subsequent play. Analytics data for this metric
    will be available for six months
    """

    video_view: Optional[float] = FieldInfo(alias="videoView", default=None)
    """VIDEO_VIEW: Video views with play-pause cycles for at least 3 seconds.

    Auto-looping videos are counted as one when loaded. Each subsequent auto-looped
    play doesn't increase this metric. Analytics data for this metric won't be
    available after six months
    """

    viewer: Optional[float] = None
    """VIEWER: Unique viewers who made engaged plays on the video.

    Auto-looping videos are counted as one when loaded. Each subsequent auto-looped
    play doesn't increase this metric. Analytics data for this metric won't be
    available after six months
    """


class MetricsBlueskyPostMetricsDto(BaseModel):
    like_count: float = FieldInfo(alias="likeCount")
    """Number of likes on the post"""

    quote_count: float = FieldInfo(alias="quoteCount")
    """Number of quotes of the post"""

    reply_count: float = FieldInfo(alias="replyCount")
    """Number of replies on the post"""

    repost_count: float = FieldInfo(alias="repostCount")
    """Number of reposts of the post"""


class MetricsPinterestPostMetricsDto_90d(BaseModel):
    """Last 90 days of Pin metrics"""

    comment: Optional[float] = None
    """Number of comments on the Pin"""

    impression: Optional[float] = None
    """Number of times the Pin was shown (impressions)"""

    last_updated: Optional[str] = None
    """The last time Pinterest updated these metrics"""

    outbound_click: Optional[float] = None
    """Number of clicks from the Pin to an external destination (outbound clicks)"""

    pin_click: Optional[float] = None
    """Number of clicks on the Pin to view it in closeup (Pin clicks)"""

    profile_visit: Optional[object] = None
    """Number of visits to the author's profile driven from the Pin"""

    reaction: Optional[float] = None
    """Total number of reactions on the Pin"""

    save: Optional[float] = None
    """Number of saves of the Pin"""

    user_follow: Optional[object] = None
    """Number of follows driven from the Pin"""

    video_10s_views: Optional[float] = None
    """Number of video views of at least 10 seconds"""

    video_average_time: Optional[float] = None
    """Average watch time for the video"""

    video_p95_views: Optional[float] = None
    """Number of video views that reached 95% completion"""

    video_total_time: Optional[float] = None
    """Total watch time for the video"""

    video_views: Optional[float] = None
    """Number of video views"""


class MetricsPinterestPostMetricsDtoLifetimeMetrics(BaseModel):
    """Lifetime Pin metrics"""

    comment: Optional[float] = None
    """Number of comments on the Pin"""

    impression: Optional[float] = None
    """Number of times the Pin was shown (impressions)"""

    last_updated: Optional[str] = None
    """The last time Pinterest updated these metrics"""

    outbound_click: Optional[float] = None
    """Number of clicks from the Pin to an external destination (outbound clicks)"""

    pin_click: Optional[float] = None
    """Number of clicks on the Pin to view it in closeup (Pin clicks)"""

    profile_visit: Optional[object] = None
    """Number of visits to the author's profile driven from the Pin"""

    reaction: Optional[float] = None
    """Total number of reactions on the Pin"""

    save: Optional[float] = None
    """Number of saves of the Pin"""

    user_follow: Optional[object] = None
    """Number of follows driven from the Pin"""

    video_10s_views: Optional[float] = None
    """Number of video views of at least 10 seconds"""

    video_average_time: Optional[float] = None
    """Average watch time for the video"""

    video_p95_views: Optional[float] = None
    """Number of video views that reached 95% completion"""

    video_total_time: Optional[float] = None
    """Total watch time for the video"""

    video_views: Optional[float] = None
    """Number of video views"""


class MetricsPinterestPostMetricsDto(BaseModel):
    api_90d: Optional[MetricsPinterestPostMetricsDto_90d] = FieldInfo(alias="90d", default=None)
    """Last 90 days of Pin metrics"""

    lifetime_metrics: Optional[MetricsPinterestPostMetricsDtoLifetimeMetrics] = None
    """Lifetime Pin metrics"""


Metrics: TypeAlias = Union[
    MetricsTikTokBusinessMetricsDto,
    MetricsTikTokPostMetricsDto,
    MetricsInstagramPostMetricsDto,
    MetricsYouTubePostMetricsDto,
    MetricsFacebookPostMetricsDto,
    MetricsTwitterPostMetricsDto,
    MetricsThreadsPostMetricsDto,
    MetricsLinkedInPostMetricsDto,
    MetricsBlueskyPostMetricsDto,
    MetricsPinterestPostMetricsDto,
]


class PlatformPost(BaseModel):
    caption: str
    """Caption or text content of the post"""

    media: List[List[object]]
    """Array of media items attached to the post"""

    platform: str
    """Social media platform name"""

    platform_account_id: str
    """Platform-specific account ID"""

    platform_post_id: str
    """Platform-specific post ID"""

    platform_url: str
    """URL to the post on the platform"""

    social_account_id: str
    """ID of the social account"""

    external_account_id: Optional[str] = None
    """External account ID from the platform"""

    external_post_id: Optional[str] = None
    """External post ID from the platform"""

    metrics: Optional[Metrics] = None
    """Post metrics and analytics data"""

    posted_at: Optional[datetime] = None
    """Date the post was published"""

    social_post_id: Optional[str] = None
    """ID of the social post"""

    social_post_result_id: Optional[str] = None
    """ID of the social post result"""
